@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco++/ncap2_utl.cc,v 1.134 2010/06/21 12:53:54 hmb Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncap2_utl.cc,v 1.137 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: netCDF arithmetic processor */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -1997,11 +1997,13 @@ ncap_cst_mk( /* [fnc] create casting var from a list of dims */
   if(var->nbr_dim > 0) var->srt=(long *)nco_malloc(var->nbr_dim*sizeof(long)); else var->srt=(long *)NULL;
   if(var->nbr_dim > 0) var->end=(long *)nco_malloc(var->nbr_dim*sizeof(long)); else var->end=(long *)NULL;
   if(var->nbr_dim > 0) var->srd=(long *)nco_malloc(var->nbr_dim*sizeof(long)); else var->srd=(long *)NULL;
+  if(var->nbr_dim > 0) var->cnk_sz=(size_t *)nco_malloc(var->nbr_dim*sizeof(size_t)); else var->cnk_sz=(size_t *)NULL;
   
   /* Defensive programming */
   var->sz=1L; 
   /* Attach LHS dimensions to variable */
   for(idx=0;idx<dmn_nbr;idx++){
+    var->cnk_sz[idx]=(size_t)0;   
     var->dim[idx]=dmn[idx];
     var->dmn_id[idx]=dmn[idx]->id;
     var->cnt[idx]=dmn[idx]->cnt;
@@ -2009,6 +2011,7 @@ ncap_cst_mk( /* [fnc] create casting var from a list of dims */
     var->end[idx]=dmn[idx]->end;
     var->srd[idx]=dmn[idx]->srd;
     var->sz*=var->cnt[idx];
+
   } /* end loop over dim */
   
 
@@ -2546,7 +2549,7 @@ char *cp_out)                   // Slab to be "put"
         cp_in+=(ptrdiff_t)cnt*slb_sz;
       }
       if(srd >1) {
-        char* cp_lcl=cp_end;
+        char *cp_lcl=cp_end;
         for(jdx=0 ; jdx<cnt ; jdx++ ){
           (void)memcpy(cp_lcl,cp_in,slb_sz);
           cp_in+=(ptrdiff_t)slb_sz;
