@@ -3,16 +3,16 @@
 
 #include <antlr/config.hpp>
 #include "ncoParserTokenTypes.hpp"
-/* $ANTLR 2.7.7 (20100319): "ncoGrammer.g" -> "ncoTree.hpp"$ */
+/* $ANTLR 2.7.7 (20100807): "ncoGrammer.g" -> "ncoTree.hpp"$ */
 #include <antlr/TreeParser.hpp>
 
 #line 1 "ncoGrammer.g"
 
-/* $Header: /cvsroot/nco/nco/src/nco++/ncoTree.hpp,v 1.101 2010/05/25 00:38:21 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco++/ncoTree.hpp,v 1.109 2010/12/29 03:47:33 zender Exp $ */
 
 /* Purpose: ANTLR Grammar and support files for ncap2 */
 
-/* Copyright (C) 2005--2010 Charlie Zender
+/* Copyright (C) 2005--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -228,21 +228,19 @@ nbr_dmn=lmt_init(lmt,ast_lmt_vtr);
      /* rec_skp_nsh_spf is used for record dimension in multi-file operators */
      lmt_ptr->rec_skp_nsh_spf=0L; /* Number of records skipped in initial superfluous files */
     
-    
-    /* Fill in structure */
+    /* Fill-in structure */
     if( lcl_ind[0] >= 0){ 
            lmt_ptr->is_usr_spc_min=True;
            lmt_ptr->srt=lcl_ind[0]; 
     }    
 
-
-    /* Fill in structure */
+    /* Fill-in structure */
     if( lcl_ind[1] >= 0) {
            lmt_ptr->is_usr_spc_max=True;
            lmt_ptr->end=lcl_ind[1];
     }    
 
-    /* Fill in structure */
+    /* Fill-in structure */
     if( lcl_ind[2] > 0) {
            lmt_ptr->srd_sng=strdup("~fill_in");
            lmt_ptr->srd=lcl_ind[2];
@@ -254,17 +252,12 @@ nbr_dmn=lmt_init(lmt,ast_lmt_vtr);
           lmt_ptr->end=lcl_ind[0]; 
     }    
 
-
     lmt_vtr.push_back(lmt_ptr);
-
-
    } // end idx
 
    return nbr_dmn;
-
 } /* end lmt_mk */
 
-
 /* Legacy run -- will remove soon
 public:
     void run(RefAST tr){
@@ -358,9 +351,7 @@ public:
    
     ntr=tr;
     do nbr_stmt++; 
-    while(ntr=ntr->getNextSibling());        
-            
-     
+    while((ntr=ntr->getNextSibling())); // 20101027 csz "while result of assignment is true" (not an equality comparison) 
     
     if(nbr_stmt <4 || nbr_dpt>0 ){
         prs_arg->ntl_scn=False;
@@ -370,7 +361,7 @@ public:
           // break if jump statement   
           if(iret==BREAK || iret==CONTINUE) 
            break; 
-        } while(ntr=ntr->getNextSibling());   
+        } while((ntr=ntr->getNextSibling())); // 20101027 csz "while result of assignment is true" (not an equality comparison) 
         goto exit;
     }
   
