@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/mpncecat.c,v 1.88 2011/02/21 20:44:42 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/mpncecat.c,v 1.89 2011/04/26 22:56:28 zender Exp $ */
 
 /* ncecat -- netCDF ensemble concatenator */
 
@@ -99,8 +99,8 @@ main(int argc,char **argv)
   
   char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
 
-  const char * const CVS_Id="$Id: mpncecat.c,v 1.88 2011/02/21 20:44:42 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.88 $";
+  const char * const CVS_Id="$Id: mpncecat.c,v 1.89 2011/04/26 22:56:28 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.89 $";
   const char * const opt_sht_lst="346ACcD:d:FHhL:l:n:Oo:p:rRSt:u:v:X:x-:";
   
   cnk_sct **cnk=NULL_CEWI;
@@ -656,7 +656,7 @@ main(int argc,char **argv)
     if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
     
     /* Turn off default filling behavior to enhance efficiency */
-    rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+    /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
     
     /* Take output file out of define mode */
     (void)nco_enddef(out_id);
@@ -809,7 +809,7 @@ main(int argc,char **argv)
 	      if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
 	      
 	      /* Turn off default filling behavior to enhance efficiency */
-	      rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+	      /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
 #else /* !ENABLE_MPI */
 #ifdef _OPENMP
 #pragma omp critical
