@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/mpncpdq.c,v 1.82 2011/01/01 02:28:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/mpncpdq.c,v 1.83 2011/04/26 22:56:28 zender Exp $ */
 
 /* mpncpdq -- netCDF pack, re-dimension, query */
 
@@ -116,8 +116,8 @@ main(int argc,char **argv)
   char add_fst_sng[]="add_offset"; /* [sng] Unidata standard string for add offset */
   char scl_fct_sng[]="scale_factor"; /* [sng] Unidata standard string for scale factor */
   
-  const char * const CVS_Id="$Id: mpncpdq.c,v 1.82 2011/01/01 02:28:48 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.82 $";
+  const char * const CVS_Id="$Id: mpncpdq.c,v 1.83 2011/04/26 22:56:28 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.83 $";
   const char * const opt_sht_lst="346Aa:CcD:d:FhL:l:M:Oo:P:p:RrSt:v:Ux-:";
   
   dmn_sct **dim=NULL_CEWI;
@@ -813,7 +813,7 @@ main(int argc,char **argv)
     if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
     
     /* Turn off default filling behavior to enhance efficiency */
-    rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+    /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
     
     /* Take output file out of define mode */
     (void)nco_enddef(out_id);
@@ -982,7 +982,7 @@ main(int argc,char **argv)
 	    if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
 	    
 	    /* Turn off default filling behavior to enhance efficiency */
-	    rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+	    /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
 #else /* !ENABLE_MPI */
 #ifdef _OPENMP
 #pragma omp critical
