@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/mpncwa.c,v 1.112 2011/01/01 02:28:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/mpncwa.c,v 1.113 2011/04/26 22:56:28 zender Exp $ */
 
 /* mpncwa -- netCDF weighted averager */
 
@@ -125,8 +125,8 @@ main(int argc,char **argv)
   char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
   char *wgt_nm=NULL;
 
-  const char * const CVS_Id="$Id: mpncwa.c,v 1.112 2011/01/01 02:28:48 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.112 $";
+  const char * const CVS_Id="$Id: mpncwa.c,v 1.113 2011/04/26 22:56:28 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.113 $";
   const char * const opt_sht_lst="346Aa:B:bCcD:d:FhIL:l:M:m:nNOo:p:rRST:t:v:Ww:xy:-:";
   
   cnk_sct **cnk=NULL_CEWI;
@@ -772,7 +772,7 @@ main(int argc,char **argv)
     if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
     
     /* Turn off default filling behavior to enhance efficiency */
-    rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+    /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
     
     /* Take output file out of define mode */
     (void)nco_enddef(out_id);
@@ -1157,7 +1157,7 @@ main(int argc,char **argv)
 	      if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
 	      
 	      /* Turn off default filling behavior to enhance efficiency */
-	      rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+	      /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
 #endif /* !ENABLE_MPI */
 	      
 #ifdef _OPENMP
