@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.150 2010/03/15 18:02:58 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.162 2011/02/21 22:38:42 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -91,17 +91,17 @@ extern "C" {
 #define float_CEWI 0.0
 #define int_CEWI 0
 #define long_CEWI 0L
-#define long_long_CEWI ((long long)0LL)
+#define long_long_CEWI ((long long int)0LL)
 #define nco_bool_CEWI 0
 #define nco_byte_CEWI ((signed char)0)
 #define nco_char_CEWI '\0'
 #define nco_int_CEWI (0L)
-#define nco_short_CEWI ((short)0)
+#define nco_short_CEWI ((short int)0)
 #define nco_ubyte_CEWI ((unsigned char)0)
-#define nco_ushort_CEWI ((unsigned short)0)
+#define nco_ushort_CEWI ((unsigned short int)0)
 #define nco_uint_CEWI (0U)
-#define nco_int64_CEWI ((long long)0LL)
-#define nco_uint64_CEWI ((unsigned long long)0ULL)
+#define nco_int64_CEWI ((long long int)0LL)
+#define nco_uint64_CEWI ((unsigned long long int)0ULL)
 #define nco_string_CEWI NULL
 #define short_CEWI 0
 #define size_t_CEWI 0UL
@@ -119,6 +119,9 @@ extern "C" {
      Initial value should be a number that will never be a true netCDF format */
 #define NCO_FORMAT_UNDEFINED 0
   
+  /* Argument to strtol() and strtoul() indicating base-10 conversions */
+#define NCO_SNG_CNV_BASE10 10
+
   /* Debugging level that quiets all non-requested informational messages
      This value is compared against user-selected dbg_lvl 
      Running operators with --quiet automatically sets dbg_lvl=NCO_DBG_QUIET */
@@ -219,6 +222,60 @@ extern "C" {
 #endif
 #ifndef NC_FORMAT_NETCDF4_CLASSIC
 # define NC_FORMAT_NETCDF4_CLASSIC  (4) /* create netcdf-4 files, with NC_CLASSIC_MODEL. */
+#endif
+
+  /* NCO began using MIN/MAX tokens in nco_pck.c on 20101130
+     Not sure when these tokens were introduced to netcdf.h */
+#ifndef NC_MAX_BYTE
+# define NC_MAX_BYTE 127
+#endif
+#ifndef NC_MIN_BYTE
+# define NC_MIN_BYTE (-NC_MAX_BYTE-1)
+#endif
+#ifndef NC_MAX_CHAR
+# define NC_MAX_CHAR 255
+#endif
+#ifndef NC_MAX_SHORT
+# define NC_MAX_SHORT 32767
+#endif
+#ifndef NC_MIN_SHORT
+# define NC_MIN_SHORT (-NC_MAX_SHORT - 1)
+#endif
+#ifndef NC_MAX_INT
+# define NC_MAX_INT 2147483647
+#endif
+#ifndef NC_MIN_INT
+# define NC_MIN_INT (-NC_MAX_INT - 1)
+#endif
+#ifndef NC_MAX_FLOAT
+# define NC_MAX_FLOAT 3.402823466e+38f
+#endif
+#ifndef NC_MIN_FLOAT
+# define NC_MIN_FLOAT (-NC_MAX_FLOAT)
+#endif
+#ifndef NC_MAX_DOUBLE
+# define NC_MAX_DOUBLE 1.7976931348623157e+308 
+#endif
+#ifndef NC_MIN_DOUBLE
+# define NC_MIN_DOUBLE (-NC_MAX_DOUBLE)
+#endif
+#ifndef NC_MAX_UBYTE
+# define NC_MAX_UBYTE NC_MAX_CHAR
+#endif
+#ifndef NC_MAX_USHORT
+# define NC_MAX_USHORT 65535U
+#endif
+#ifndef NC_MAX_UINT
+# define NC_MAX_UINT 4294967295U
+#endif
+#ifndef NC_MAX_INT64
+# define NC_MAX_INT64 (9223372036854775807LL)
+#endif
+#ifndef NC_MIN_INT64
+# define NC_MIN_INT64 (-9223372036854775807LL-1)
+#endif
+#ifndef NC_MAX_UINT64
+# define NC_MAX_UINT64 (18446744073709551615ULL)
 #endif
 /* Endif older netcdf.h */
 
@@ -340,32 +397,42 @@ extern "C" {
   } nod_typ_enm; /* end Node enumerator */
   /* end enumeration section */
 
+  typedef enum { /* [enm] Calendar type */
+    cln_std=1, /* Standard mixed Julian/Gregorian */
+    cln_grg, /* Gregorian Calendar */ 
+    cln_jul, /* Julian Calendar */ 
+    cln_360 , /* 30 days a month Calendar */ 
+    cln_365, /* No Leap year Calendar */ 
+    cln_366, /* Leap year Calendar */ 
+    cln_nil /* No calendar found */
+  } cln_typ; /* [enm] Calendar type */
+  
   /* Limit structure */
   typedef struct { /* lmt_sct */
-    char *nm; /* [sng] Dimension name */
-    int lmt_typ; /* crd_val or dmn_idx */
     /* Following four flags are used only by multi-file operators ncra and ncrcat: */
-    nco_bool is_usr_spc_lmt; /* True if any part of limit is user-specified, else False */
-    nco_bool is_usr_spc_min; /* True if user-specified, else False */
-    nco_bool is_usr_spc_max; /* True if user-specified, else False */
-    nco_bool is_rec_dmn; /* True if record dimension, else False */
-    long rec_skp_vld_prv; /* Records skipped since prevous good one (multi-file record dimension only) */
-    long rec_skp_nsh_spf; /* Sum of records in already processed files (multi-file record dimension only) */
-    char *min_sng; /* User-specified string for dimension minimum */
     char *max_sng; /* User-specified string for dimension maximum */
+    char *min_sng; /* User-specified string for dimension minimum */
+    char *nm; /* [sng] Dimension name */
+    char *rbs_sng; /* Used by ncra, ncrcat to re-base record coordinate (holds unit attribute from first file) */
     char *srd_sng; /* User-specified string for dimension stride */
-    int id; /* Dimension ID */
-    long min_idx; /* Index of minimum requested value in dimension */
-    long max_idx; /* Index of maximum requested value in dimension */
-    double min_val; /* Double precision representation of minimum value of coordinate requested or implied */
+    cln_typ lmt_cln; /* Used by ncra, ncrcat to store an enum of the calendar type attribute */
     double max_val; /* Double precision representation of maximum value of coordinate requested or implied */
-    long srt; /* Index to start of hyperslab */
-    long end; /* Index to end of hyperslab */
+    double min_val; /* Double precision representation of minimum value of coordinate requested or implied */
+    double origin;   /* Used by ncra, ncrcat to re-base record coordinate */
+    int id; /* Dimension ID */
+    int lmt_typ; /* crd_val or dmn_idx */
     long cnt; /* # of valid elements in this dimension (including effects of stride and wrapping) */
+    long end; /* Index to end of hyperslab */
+    long max_idx; /* Index of maximum requested value in dimension */
+    long min_idx; /* Index of minimum requested value in dimension */
+    long rec_skp_nsh_spf; /* Sum of records in already processed files (multi-file record dimension only) */
+    long rec_skp_vld_prv; /* Records skipped since prevous good one (multi-file record dimension only) */
     long srd; /* Stride of hyperslab */
-    double origin;   /* used for ncra,ncrcat to time rebase co-ordinate var */
-    char *re_bs_sng; /* used for ncra,ncrcat to time rebase co-ordinate -holds unit attribue from first file */
-    int lmt_cal; /* used for ncra,ncrcat to store an enum of the calendar type attribute */
+    long srt; /* Index to start of hyperslab */
+    nco_bool is_rec_dmn; /* True if record dimension, else False */
+    nco_bool is_usr_spc_lmt; /* True if any part of limit is user-specified, else False */
+    nco_bool is_usr_spc_max; /* True if user-specified, else False */
+    nco_bool is_usr_spc_min; /* True if user-specified, else False */
   } lmt_sct;
 
   /* Container holding all limit structures indexible by dimension */
@@ -483,20 +550,20 @@ extern "C" {
   /* Dimension structure */
   typedef struct dmn_sct_tag{ /* dmn_sct */
     char *nm; /* [sng] Dimension name */
+    char fmt[5]; /* [sng] Hint for printf()-style formatting */
+    int cid; /* [id] Variable ID of associated coordinate, if any */
     int id; /* [id] Dimension ID */
     int nc_id; /* [id] File ID */
-    long sz; /* [nbr] Full size of dimension in file (NOT the hyperslabbed size) */
-    short is_rec_dmn; /* [flg] Is this the record dimension? */
-    short is_crd_dmn; /* [flg] Is this a coordinate dimension? */
-    int cid; /* [id] Variable ID of associated coordinate, if any */
-    nc_type type; /* [enm] Type of coordinate, if applicable */
-    char fmt[5]; /* [sng] Hint for printf()-style formatting */
-    long srt; /* [idx] Index to start of hyperslab */
-    long end; /* [idx] Index to end of hyperslab */
     long cnt; /* [nbr] Number of valid elements in this dimension (including effects of stride and wrapping) */
+    long end; /* [idx] Index to end of hyperslab */
     long srd; /* [nbr] Stride of hyperslab */
-    size_t cnk_sz; /* [nbr] Chunk size */
+    long srt; /* [idx] Index to start of hyperslab */
+    long sz; /* [nbr] Full size of dimension in file (NOT the hyperslabbed size) */
+    nc_type type; /* [enm] Type of coordinate, if applicable */
     ptr_unn val; /* [sct] Buffer to hold hyperslab fxm: is this ever used? */
+    short is_crd_dmn; /* [flg] Is this a coordinate dimension? */
+    short is_rec_dmn; /* [flg] Is this the record dimension? */
+    size_t cnk_sz; /* [nbr] Chunk size */
     struct dmn_sct_tag *xrf; /* [sct] Cross-reference to associated dimension structure (usually the structure for dimension on output) */
   } dmn_sct; /* end dmn_sct_tag */
   
@@ -507,41 +574,43 @@ extern "C" {
   /* Variable structure */
   typedef struct var_sct_tag{ /* var_sct */
     char *nm; /* [sng] Variable name */
-    int id; /* [id] Variable ID */
-    int nc_id; /* [id] File ID */
-    int nbr_dim; /* [nbr] Number of dimensions of variable in input file */
-    nc_type type; /* [enm] Type of variable in RAM */
-    nc_type typ_dsk; /* [enm] Type of variable on disk (never changes) */
-    short is_rec_var; /* [flg] Is this a record variable? */
-    short is_crd_var; /* [flg] Is this a coordinate variable? */
-    long sz; /* [nbr] Number of elements (NOT bytes) in hyperslab (NOT full size of variable in input file!) */
-    long sz_rec; /* [nbr] Number of elements in one record of hyperslab */
-    int nbr_att; /* [nbr] Number of attributes */
-    int has_dpl_dmn; /* [flg] Variable has duplicate copies of same dimension */
-    int has_mss_val; /* [flg] Is there a missing_value attribute? */
-    ptr_unn mss_val; /* [frc] Value of missing_value attribute, if any (mss_val stored in this structure must be same type as variable) */
-    int cid; /* [id] Dimension ID of associated coordinate, if any */
     char fmt[5]; /* [sng] Hint for printf()-style formatting */
     dmn_sct **dim; /* [sct] Pointers to full dimension structures */
     int *dmn_id; /* [id] Contiguous vector of dimension IDs */
-    size_t *cnk_sz; /* [id] Contiguous vector of chunk sizes */
-    long *srt; /* [id] Contiguous vector of indices to start of hyperslab */
-    long *end; /* [id] Contiguous vector of indices to end of hyperslab */
-    long *cnt; /* [id] Contiguous vector of lengths of hyperslab */
-    long *srd; /* [id] Contiguous vector of stride of hyperslab */
-    ptr_unn val; /* [bfr] Buffer to hold hyperslab */
-    long *tally; /* [nbr] Number of valid operations performed so far */
-    struct var_sct_tag *xrf; /* [sct] Cross-reference to associated variable structure (usually structure for variable on output) fxm: deprecate! TODO nco226 */
+    int cid; /* [id] Dimension ID of associated coordinate, if any */
+    int dfl_lvl; /* [enm] Deflate level [0..9] */
+    int has_add_fst; /* [flg] Valid add_offset attribute exists */
+    int has_dpl_dmn; /* [flg] Variable has duplicate copies of same dimension */
+    int has_mss_val; /* [flg] Is there a missing_value attribute? */
+    int has_scl_fct; /* [flg] Valid scale_factor attribute exists */
+    int id; /* [id] Variable ID */
+    int nbr_att; /* [nbr] Number of attributes */
+    int nbr_dim; /* [nbr] Number of dimensions of variable in input file */
+    int nc_id; /* [id] File ID */
     int pck_dsk; /* [flg] Variable is packed on disk (valid scale_factor, add_offset, or both attributes exist) */
     int pck_ram; /* [flg] Variable is packed in memory (valid scale_factor, add_offset, or both attributes exist) */
-    int has_scl_fct; /* [flg] Valid scale_factor attribute exists */
-    int has_add_fst; /* [flg] Valid add_offset attribute exists */
-    ptr_unn scl_fct; /* [frc] Value of scale_factor attribute of type typ_upk */
-    ptr_unn add_fst; /* [frc] Value of add_offset attribute of type typ_upk */
+    int shuffle; /* [flg] Turn on shuffle filter */
+    int undefined; /* [flg] Variable is still undefined (in first parser pass) */
+    long *cnt; /* [id] Contiguous vector of lengths of hyperslab */
+    long *end; /* [id] Contiguous vector of indices to end of hyperslab */
+    long *srd; /* [id] Contiguous vector of stride of hyperslab */
+    long *srt; /* [id] Contiguous vector of indices to start of hyperslab */
+    long *tally; /* [nbr] Number of valid operations performed so far */
+    long sz; /* [nbr] Number of elements (NOT bytes) in hyperslab (NOT full size of variable in input file!) */
+    long sz_rec; /* [nbr] Number of elements in one record of hyperslab */
+    nc_type typ_dsk; /* [enm] Type of variable on disk (never changes) */
     nc_type typ_pck; /* [enm] Type of variable when packed (on disk). typ_pck = typ_dsk except in cases where variable is packed in input file and unpacked in output file. */
     nc_type typ_upk; /* [enm] Type of variable when unpacked (expanded) (in memory) */
-    int undefined; /* [flg] Variable is still undefined (in first parser pass) */
-    int is_fix_var; /* [flg] Is this a fixed (non-processed) variable? */
+    nc_type type; /* [enm] Type of variable in RAM */
+    ptr_unn add_fst; /* [frc] Value of add_offset attribute of type typ_upk */
+    ptr_unn mss_val; /* [frc] Value of missing_value attribute, if any (mss_val stored in this structure must be same type as variable) */
+    ptr_unn scl_fct; /* [frc] Value of scale_factor attribute of type typ_upk */
+    ptr_unn val; /* [bfr] Buffer to hold hyperslab */
+    short is_crd_var; /* [flg] Is this a coordinate variable? */
+    short is_fix_var; /* [flg] Is this a fixed (non-processed) variable? */
+    short is_rec_var; /* [flg] Is this a record variable? */
+    size_t *cnk_sz; /* [id] Contiguous vector of chunk sizes */
+    struct var_sct_tag *xrf; /* [sct] Cross-reference to associated variable structure (usually structure for variable on output) fxm: deprecate! TODO nco226 */
   } var_sct; /* end var_sct_tag */
   
 #ifdef __cplusplus
