@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.h,v 1.9 2010/04/29 19:06:42 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_aux.h,v 1.13 2011/02/21 23:20:20 zender Exp $ */
 
-/* Purpose: Sub-set cell-based grids using auxillary coordinate variable */
+/* Purpose: Sub-set cell-based grids using auxiliary coordinate variable */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -34,11 +34,9 @@ nco_aux_evl
 (int in_id, 
  int aux_nbr, 
  char *aux_arg[],
- int *lmt_nbr
- );
+ int *lmt_nbr);
 
-
-int 
+int
 nco_find_lat_lon
 (int ncid, 
  char var_nm_lat[], 
@@ -46,9 +44,7 @@ nco_find_lat_lon
  char **units,
  int *lat_id,
  int *lon_id,
- nc_type *crd_typ
- );
-
+ nc_type *crd_typ);
 
 int
 nco_get_dmn_info
@@ -56,18 +52,16 @@ nco_get_dmn_info
  int varid,
  char dimname[],
  int *dimid,
- long *dmn_sz
-);
+ long *dmn_sz);
 
 void 
 nco_aux_prs
-(const char *args, 
+(const char *bnd_bx_sng, 
  const char *units, 
- float *lllon, 
- float *lllat, 
- float *urlon, 
- float *urlat
- );
+ float *lon_min, 
+ float *lon_max, 
+ float *lat_min, 
+ float *lat_max);
 
 #ifdef __cplusplus
 } /* end extern "C" */
