@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.26 2010/04/18 17:59:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnk.c,v 1.32 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: NCO utilities for chunking */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -25,6 +25,9 @@
    ncecat -O -4 -D 4 --cnk_plc=all -p ~/nco/data in.nc in.nc ~/foo.nc
    ncecat -O -4 -D 4 --cnk_plc=g2d --cnk_map=rd1 --cnk_dmn lat,64 --cnk_dmn lon,128 -p ${DATA}/dstmch90 dstmch90_clm.nc dstmch90_clm.nc ~/foo.nc
 
+   ncwa testing:
+   ncwa -O -4 -D 4 -a time --cnk_plc=g2d --cnk_map=rd1 --cnk_dmn lat,32 --cnk_dmn lon,128 -p ${DATA}/dstmch90 dstmch90_clm_0112.nc ~/foo.nc
+
    Advanced Chunking:
    http://hdfeos.org/workshops/ws13/presentations/day1/HDF5-EOSXIII-Advanced-Chunking.ppt */
 
@@ -117,6 +120,7 @@ nco_cnk_prs /* [fnc] Create chunking structures with name and chunksize elements
   void nco_usg_prn(void);
   
   char **arg_lst;
+  char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
   
   const char dlm_sng[]=",";
   
@@ -151,9 +155,10 @@ nco_cnk_prs /* [fnc] Create chunking structures with name and chunksize elements
     cnk[idx]->nm=NULL;
     cnk[idx]->is_usr_spc_cnk=True; /* True if any part of limit is user-specified, else False */
     
-    /* Fill in structure */
+    /* Fill-in structure */
     cnk[idx]->nm=arg_lst[0];
-    cnk[idx]->sz=strtoul(arg_lst[1],(char **)NULL,10);
+    cnk[idx]->sz=strtoul(arg_lst[1],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[1],"strtoul",sng_cnv_rcd);
     
     /* Free current pointer array to strings
        Strings themselves are untouched and will be free()'d with chunk structures 
