@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_cnv_csm.c,v 1.47 2010/01/27 09:36:31 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_cnv_csm.c,v 1.54 2011/01/01 02:28:48 zender Exp $ */
 
 /* Purpose: CCM/CCSM/CF conventions */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -19,8 +19,8 @@ nco_cnv_ccm_ccsm_cf_inq /* O [fnc] Check if file obeys CCM/CCSM/CF conventions *
   char *att_val;
   char *cnv_sng=NULL_CEWI;
 
-  /* netCDF standard is uppercase Conventions, but some models user lowercase */
-  char cnv_sng_UC[]="Conventions"; /* Unidata standard string (uppercase) */
+  /* netCDF standard is uppercase Conventions, though some models user lowercase */
+  char cnv_sng_UC[]="Conventions"; /* Unidata standard     string (uppercase) */
   char cnv_sng_LC[]="conventions"; /* Unidata non-standard string (lowercase) */
   
   int rcd; /* [rcd] Return code */
@@ -29,15 +29,14 @@ nco_cnv_ccm_ccsm_cf_inq /* O [fnc] Check if file obeys CCM/CCSM/CF conventions *
 
   nc_type att_typ;
 
-  /* Look for signature of an CCM/CCSM/CF format file */
+  /* Look for signature of a CCM/CCSM/CF-format file */
   cnv_sng=cnv_sng_UC;
   rcd=nco_inq_att_flg(nc_id,NC_GLOBAL,cnv_sng,&att_typ,&att_sz);
   if(rcd != NC_NOERR){
-    /* Some models, e.g., CLM user lowercase "conventions" */
+    /* Re-try with lowercase string because some models, e.g., CLM, user lowercase "conventions" */
     cnv_sng=cnv_sng_LC;
     rcd=nco_inq_att_flg(nc_id,NC_GLOBAL,cnv_sng,&att_typ,&att_sz);
-
-  } /* Re-try with lowercase string */
+  } /* endif lowercase */
   
   if(rcd == NC_NOERR && att_typ == NC_CHAR){
     /* Add one for NUL byte */
@@ -55,7 +54,7 @@ nco_cnv_ccm_ccsm_cf_inq /* O [fnc] Check if file obeys CCM/CCSM/CF conventions *
       (void)fprintf(stderr,"%s: CONVENTION File \"%s\" attribute is \"%s\"\n",prg_nm_get(),cnv_sng,att_val);
       if(cnv_sng == cnv_sng_LC) (void)fprintf(stderr,"%s: WARNING: This file uses a non-standard attribute (\"%s\") to indicate the netCDF convention. The correct attribute is \"%s\".\n",prg_nm_get(),cnv_sng_LC,cnv_sng_UC);
       /* Only warn in arithmetic operators where conventions change behavior */
-      if(dbg_lvl_get() > 1 && nco_is_rth_opr(prg_get())) (void)fprintf(stderr,"%s: INFO NCO has a unified (though incomplete) treatment of many related (official and unoffical) conventions including the older CCM and CCSM and newer CF conventions. To adhere to these conventions, NCO implements variable-specific exceptions in certain operators, e.g., ncbo will not subtract variables named \"date\" or \"gw\". The full list of exceptions is in the manual http://nco.sf.net/nco.html#CF\n",prg_nm_get());
+      if(dbg_lvl_get() > 1 && nco_is_rth_opr(prg_get())) (void)fprintf(stderr,"%s: INFO NCO has a unified (though incomplete) treatment of many related (official and unoffical) conventions including the older CCM and CCSM and newer CF conventions. To adhere to these conventions, NCO implements variable-specific exceptions in certain operators, e.g., ncbo will not subtract variables named \"date\" or \"gw\", and many operators will always leave coordinate variables unchanged. The full list of exceptions is in the manual http://nco.sf.net/nco.html#CF\n",prg_nm_get());
     } /* endif dbg */
     att_val=(char *)nco_free(att_val);
   } /* endif */
@@ -78,12 +77,11 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
   int rcd=NC_NOERR; /* [rcd] Return code */
   int time_idx;
   
-  long day;
-
   int nbdate_id;
   
-  nco_int nbdate;
+  nco_int day;
   nco_int date;
+  nco_int nbdate;
   
   (void)sprintf(wrn_sng,"Most, but not all, CCM/CCSM/CF files which are in CCM format contain the fields \"nbdate\", \"time\", and \"date\". When the \"date\" field is present but either \"nbdate\" or \"time\" is missing, then %s is unable to construct a meaningful average \"date\" to store in the output file. Therefore the \"date\" variable in your output file may be meaningless.\n",prg_nm_get());
 
@@ -92,7 +90,7 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
     if(!strcmp(var[idx]->nm,"date")) break;
   } /* end loop over idx */
   if(idx == nbr_var) return; else date_idx=idx;
-  if(var[date_idx]->type != NC_INT) return;
+  // if(var[date_idx]->type != NC_INT) return; /* 20101026 TODO nco998 problem is that "date" type is NC_DOUBLE here */
   
   /* Find scalar nbdate variable (NC_INT: base date date as 6 digit integer (YYMMDD)) */
   rcd=nco_inq_varid_flg(nc_id,"nbdate",&nbdate_id);
@@ -107,12 +105,12 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
     (void)nco_get_var1(nc_id,nbdate_id,0L,&nbdate,NC_INT);
   } /* end potential OpenMP critical */
   
-  /* Find time variable (NC_DOUBLE: current day) */
+  /* Find time variable (NC_DOUBLE: current day since nbdate) */
   for(idx=0;idx<nbr_var;idx++){
     if(!strcmp(var[idx]->nm,"time")) break;
   } /* end loop over idx */
   if(idx == nbr_var){
-    (void)fprintf(stderr,"%s: WARNING CCM/CCSM/CF convention file output variable list contains \"date\" but not \"time\"\n",prg_nm_get());
+    (void)fprintf(stderr,"%s: WARNING CCM/CCSM/CF convention file output variable list contains \"date\" and \"nbdate\" yet lacks \"time\"\n",prg_nm_get());
     (void)fprintf(stderr,"%s: %s",prg_nm_get(),wrn_sng);
     return;
   }else{
@@ -120,7 +118,7 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
   } /* endif */
   
   /* Assign current day to averaged day number */
-  day=(long)(var[time_idx]->val.dp[0]);
+  day=(nco_int)(var[time_idx]->val.dp[0]);
   
   /* Recompute date variable based on new (averaged) day number */
 #ifdef USE_FORTRAN_ARITHMETIC
@@ -128,7 +126,13 @@ nco_cnv_ccm_ccsm_cf_date /* [fnc] Fix date variable in averaged CCM/CCSM/CF file
 #else /* !USE_FORTRAN_ARITHMETIC */
   date=nco_newdate(nbdate,day);
 #endif /* !USE_FORTRAN_ARITHMETIC */
-  if(var[date_idx]->val.ip) return; else var[date_idx]->val.ip[0]=date;
+  if(var[date_idx]->type == NC_INT){
+    if(!var[date_idx]->val.ip) return; else var[date_idx]->val.ip[0]=date;
+  }else if(var[date_idx]->type == NC_DOUBLE){
+    if(!var[date_idx]->val.dp) return; else var[date_idx]->val.dp[0]=date;
+  }else{
+    (void)fprintf(stderr,"%s: WARNING CCM/CCSM/CF convention file output variable \"date\" is not NC_INT or NC_DOUBLE\n",prg_nm_get());
+  } /* end else */
   
   return; /* 20050109: fxm added return to void function to squelch erroneous gcc-3.4.2 warning */ 
 } /* end nco_cnv_ccm_ccsm_cf_date */
