@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_ctl.h,v 1.34 2010/01/05 20:02:17 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_ctl.h,v 1.39 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: Program flow control functions */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -13,7 +13,7 @@
 #define NCO_CTL_H
 
 #ifdef HAVE_CONFIG_H
-#include <config.h> /* Autotools tokens */
+# include <config.h> /* Autotools tokens */
 #endif /* !HAVE_CONFIG_H */
 
 /* Standard header files */
@@ -33,6 +33,7 @@
 /* Personal headers */
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_mmr.h" /* Memory management */
+#include "nco_pck.h" /* Packing and unpacking variables */
 #include "nco_sng_utl.h" /* String utilities */
 
 #ifdef __cplusplus
@@ -54,8 +55,9 @@ nco_is_rth_opr /* [fnc] Query whether program does arithmetic */
 (const int prg_id); /* [enm] Program ID */
 
 nco_bool /* [flg] Program does arithmetic and preserves rank */
-nco_is_rnk_prs_rth_opr /* [fnc] Is program rank-preserving arithmetic operator? */
-(const int prg_id); /* [enm] Program ID */
+nco_is_sz_rnk_prv_rth_opr /* [fnc] Is program size and rank-preserving arithmetic operator? */
+(const int prg_id, /* I [enm] Program ID */
+ const int nco_pck_plc); /* I [enm] Packing policy */
 
 nco_bool /* [flg] Program is multi-file operator */
 nco_is_mlt_fl_opr /* [fnc] Query whether program is multi-file operator */
