@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.c,v 1.38 2010/01/26 13:06:25 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_dmn_utl.c,v 1.43 2011/01/04 02:21:13 zender Exp $ */
 
 /* Purpose: Dimension utilities */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -59,6 +59,23 @@ nco_dmn_dpl /* [fnc] Duplicate input dimension structure */
   return dmn_cpy;
 } /* end nco_dmn_dpl() */
 
+void 
+nco_dmn_cpy /* [fnc] Copy dim elements from dim from source to target */
+(dmn_sct * const dmn_t, /* O [sct] Dimension structure to copy into */
+ const dmn_sct * const dmn_s) /* I [sct] Dimension structure to copy from */
+{
+  if(dmn_t->nm)
+    dmn_t->nm=(char*)nco_free(dmn_t->nm);
+
+  /* shallow copy elements */
+  *dmn_t=*dmn_s;   
+  
+  /* re-copy name */
+  dmn_t->nm=strdup(dmn_s->nm);
+  return;
+} /* end nco_dmn_cpy() */
+  
+
 dmn_sct * /* O [sct] Output dimension structure */
 nco_dmn_fll /* [fnc] Create and return completed dmn_sct */
 (const int nc_id, /* I [id] netCDF input file ID */
@@ -81,6 +98,7 @@ nco_dmn_fll /* [fnc] Create and return completed dmn_sct */
   dmn->val.vp=NULL;
 
   dmn->is_crd_dmn=False;
+  dmn->cid=-1; /* [id] Variable ID of associated coordinate, if any */
   (void)nco_inq_dimlen(dmn->nc_id,dmn_id,&dmn->sz);
   
   /* Get record dimension ID */
@@ -324,44 +342,33 @@ nco_dmn_xrf  /* [fnc] Crossreference xrf elements of dimension structures */
   dmn_2->xrf=dmn_1;
 } /* end nco_dmn_xrf() */
 
-
-
 void 
 nco_dmn_sct_cmp   /* [fnc] Check that dims in list 2 are a subset of list 1 and that they are the same size */
 (dmn_sct ** const dim_1, /* I [sct] Dimension list 1 */
  const int nbr_dmn_1,  /* I [nbr] Number of dimension structures in structure list */
  dmn_sct **const dim_2,  /* I [sct] Dimension list 1 */
  const int nbr_dmn_2,  /* I [nbr] Number of dimension structures in structure list */
- const char* const fl_sng_1, /* I [sng] Name of first file */
+ const char *const fl_sng_1, /* I [sng] Name of first file */
  const char *fl_sng_2)       /* I [sng] Name of second file */
 {
-
   int idx;
   int jdx;
 
-  for(idx=0 ; idx<nbr_dmn_2 ; idx++ ){
-    for(jdx=0 ; jdx<nbr_dmn_1 ; jdx++) 
-       if(!strcmp(dim_2[idx]->nm,dim_1[jdx]->nm))
-	     break;
+  for(idx=0;idx<nbr_dmn_2;idx++ ){
+    for(jdx=0;jdx<nbr_dmn_1;jdx++) 
+      if(!strcmp(dim_2[idx]->nm,dim_1[jdx]->nm)) break;
 		 		
-	if(jdx==nbr_dmn_1) {	 	   
-     (void)fprintf(stderr,"%s: ERROR dim \"%s\" in second file %s - not present in first file %s\n",prg_nm_get(),dim_2[idx]->nm,fl_sng_2,fl_sng_1);
-       nco_exit(EXIT_FAILURE);
-    }  
+    if(jdx == nbr_dmn_1){
+      (void)fprintf(stderr,"%s: ERROR dimension \"%s\" in second file %s is not present in first file %s\n",prg_nm_get(),dim_2[idx]->nm,fl_sng_2,fl_sng_1);
+      nco_exit(EXIT_FAILURE);
+    } /* end if missing dimension */
 	
-	if(dim_2[idx]->cnt != dim_1[jdx]->cnt){
-	   if(dim_1[jdx]->is_rec_dmn)    
-	     (void)fprintf(stderr,"%s: ERROR record dimension mismatch : record dim file in %s is %li : record dim file in %s is %li\n",prg_nm_get(),fl_sng_1,dim_1[jdx]->cnt, fl_sng_2,dim_2[idx]->cnt);     
-	   else	      
-		 (void)fprintf(stderr,"%s: ERROR dimension mismatch :  dim \"%s\" in file %s is %li : in file  %s it is %li\n",prg_nm_get(),dim_1[jdx]->nm, fl_sng_1,dim_1[jdx]->cnt, fl_sng_2,dim_2[idx]->cnt);
-		nco_exit(EXIT_FAILURE); 
-	}	
-				
-
-  } 
- 
-
-} /* end nco_dmn_sct_cmp */
+    if(dim_2[idx]->cnt != dim_1[jdx]->cnt){
+      (void)fprintf(stderr,"%s: ERROR %sdimension size mismatch: dimension %s in file %s is size %li while dimension %s in file %s is size %li\n",prg_nm_get(),(dim_1[jdx]->is_rec_dmn) ? "record " : "",dim_1[jdx]->nm,fl_sng_1,dim_1[jdx]->cnt,dim_2[idx]->nm,fl_sng_2,dim_2[idx]->cnt);
+      nco_exit(EXIT_FAILURE); 
+    } /* endif size mismatch */
+  } /* end loop over dimensions */
+} /* end nco_dmn_sct_cmp() */
 
 
 
