@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_lmt.c,v 1.100 2010/03/08 09:56:38 hmb Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_lmt.c,v 1.112 2011/02/21 22:38:42 zender Exp $ */
 
 /* Purpose: Hyperslab limits */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -18,7 +18,7 @@ nco_lmt_free /* [fnc] Free memory associated with limit structure */
   lmt->min_sng=(char *)nco_free(lmt->min_sng);
   lmt->max_sng=(char *)nco_free(lmt->max_sng);
   lmt->srd_sng=(char *)nco_free(lmt->srd_sng);
-  lmt->re_bs_sng=(char*)nco_free(lmt->re_bs_sng);   
+  lmt->rbs_sng=(char*)nco_free(lmt->rbs_sng);   
   
   lmt=(lmt_sct *)nco_free(lmt);
   
@@ -128,7 +128,7 @@ nco_lmt_sct_mk /* [fnc] Create stand-alone limit structure for given dimension *
     long cnt;
     int max_sng_sz;
     
-    /* Fill in limits with default parsing information */
+    /* Fill-in limits with default parsing information */
     rcd=nco_inq_dim_flg(nc_id,dmn_id,dmn_nm,&cnt);
     
     if(rcd == NC_EBADDIM){
@@ -153,7 +153,7 @@ nco_lmt_sct_mk /* [fnc] Create stand-alone limit structure for given dimension *
        arguments with strings as if they had been read from keyboard.
        An alternate solution is to add flag to lmt_sct indicating whether this
        limit struct had been automatically generated and then act accordingly. */
-    /* Decrement cnt to C index value if necessary */
+    /* Decrement cnt to C-index value if necessary */
     if(!FORTRAN_IDX_CNV) cnt--; 
     if(cnt < 0L){
       if(cnt == -1L) (void)fprintf(stdout,"%s: ERROR nco_lmt_sct_mk() reports record variable exists and is size zero, i.e., has no records yet.\n",prg_nm_get());
@@ -190,9 +190,13 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
      maxima strings and find appropriate indices into dimensions 
      for formulation of dimension start and count vectors, or fail trying. */
   
+  nco_bool flg_no_data_error=False; /* True if domain brackets no data (and not an MFO/record coord) */
   nco_bool flg_no_data=False; /* True if file contains no data for hyperslab */
   nco_bool rec_dmn_and_mlt_fl_opr=False; /* True if record dimension in multi-file operator */
   
+  char *fl_udu_sng=NULL_CEWI;   /* store units attribute of co-ordinate dim */
+  char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
+  
   dmn_sct dim;
   
   enum monotonic_direction{
@@ -203,19 +207,16 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
   
   int min_lmt_typ=int_CEWI;
   int max_lmt_typ=int_CEWI;
-  int monotonic_direction;
+  int monotonic_direction=decreasing; /* CEWI */
   int prg_id; /* Program ID */
   int rcd=NC_NOERR; /* [enm] Return code */
   int rec_dmn_id; /* [idx] Variable ID of record dimension, if any */
   
-  long idx;
   long dmn_sz;
   long cnt_rmn_crr=-1L; /* Records to extract from current file */
   long cnt_rmn_ttl=-1L; /* Total records remaining to be read from this and all remaining files */
   long rec_skp_vld_prv_dgn=-1L; /* Records skipped at end of previous valid file (diagnostic only) */
   
-  char *fl_udu_sng=NULL_CEWI;   /* store units attribute of co-ordinate dim */
-  
   lmt=*lmt_ptr;
   
   prg_id=prg_get(); /* Program ID */
@@ -234,9 +235,9 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
   
   /* Logic on whether to allow skipping current file depends on whether limit
      is specified for record dimension in multi-file operators.
-     This information is not used in single-file operators, but whether
+     This information is not used in single-file operators, though whether
      the limit is a record limit may be tested.
-     Best to program defensively and define this flag in all cases. */
+     Program defensively and define this flag in all cases. */
   (void)nco_inq(nc_id,(int *)NULL,(int *)NULL,(int *)NULL,&rec_dmn_id);
   if(lmt.id == rec_dmn_id) lmt.is_rec_dmn=True; else lmt.is_rec_dmn=False;
   if(lmt.is_rec_dmn && (prg_id == ncra || prg_id == ncrcat)) rec_dmn_and_mlt_fl_opr=True; else rec_dmn_and_mlt_fl_opr=False;
@@ -258,7 +259,8 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       (void)fprintf(stdout,"%s: ERROR Requested stride for \"%s\", %s, must be integer\n",prg_nm_get(),lmt.nm,lmt.srd_sng);
       nco_exit(EXIT_FAILURE);
     } /* end if */
-    lmt.srd=strtol(lmt.srd_sng,(char **)NULL,10);
+    lmt.srd=strtol(lmt.srd_sng,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(lmt.srd_sng,"strtol",sng_cnv_rcd);
     if(lmt.srd < 1){
       (void)fprintf(stdout,"%s: ERROR Stride for \"%s\" is %li but must be > 0\n",prg_nm_get(),lmt.nm,lmt.srd);
       nco_exit(EXIT_FAILURE);
@@ -286,42 +288,36 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
   if(min_lmt_typ != max_lmt_typ){
     (void)fprintf(stdout,"%s: ERROR -d %s,%s,%s\n",prg_nm_get(),lmt.nm,lmt.min_sng,lmt.max_sng);
     (void)fprintf(stdout,"Limits on dimension \"%s\" must be of same numeric type:\n",lmt.nm);
-    (void)fprintf(stdout,"\"%s\" was interpreted as a %s.\n",lmt.min_sng,(min_lmt_typ == lmt_crd_val) ? "coordinate value" : "zero-based dimension index");
-    (void)fprintf(stdout,"\"%s\" was interpreted as a %s.\n",lmt.max_sng,(max_lmt_typ == lmt_crd_val) ? "coordinate value" : "zero-based dimension index");
-    (void)fprintf(stdout,"(Limit arguments containing a decimal point are interpreted as coordinate values; arguments without a decimal point are interpreted as zero-based dimensional indices.)\n");
+    (void)fprintf(stdout,"\"%s\" was interpreted as a %s.\n",lmt.min_sng,(min_lmt_typ == lmt_crd_val) ? "coordinate value" : (FORTRAN_IDX_CNV) ? "one-based dimension index" : "zero-based dimension index");
+    (void)fprintf(stdout,"\"%s\" was interpreted as a %s.\n",lmt.max_sng,(max_lmt_typ == lmt_crd_val) ? "coordinate value" : (FORTRAN_IDX_CNV) ? "one-based dimension index" : "zero-based dimension index");
+    (void)fprintf(stdout,"(Limit arguments containing a decimal point are interpreted as coordinate values; arguments without a decimal point are interpreted as zero-based or one-based (depending on -F switch) dimensional indices.)\n");
     nco_exit(EXIT_FAILURE);
   } /* end if */
   lmt.lmt_typ=min_lmt_typ;
   
-  /* co-ordinate rebasing code */
+  /* Coordinate re-basing code */
   lmt.origin=0.0;
   /* Get variable ID of coordinate */
   rcd=nco_inq_varid_flg(nc_id,lmt.nm,&dim.cid);
-  if(rcd==NC_NOERR){
-    char *cal_sng=NULL_CEWI;
+  if(rcd == NC_NOERR){
+    char *cln_sng=NULL_CEWI;
     
     fl_udu_sng=nco_lmt_get_udu_att(nc_id,dim.cid,"units"); /* units attribute of co-ordinate var */
-    cal_sng=nco_lmt_get_udu_att(nc_id,dim.cid,"calendar"); /* calendar attribute */
+    cln_sng=nco_lmt_get_udu_att(nc_id,dim.cid,"calendar"); /* calendar attribute */
     
-    if(rec_dmn_and_mlt_fl_opr && fl_udu_sng && lmt.re_bs_sng){ 
+    if(rec_dmn_and_mlt_fl_opr && fl_udu_sng && lmt.rbs_sng){ 
 #ifdef ENABLE_UDUNITS
       /* Re-base and reset origin to 0.0 if re-basing fails */
-      if(nco_cln_clc_org(fl_udu_sng,lmt.re_bs_sng,lmt.lmt_cal,&lmt.origin)!=EXIT_SUCCESS) lmt.origin=0.0;
+      if(nco_cln_clc_org(fl_udu_sng,lmt.rbs_sng,lmt.lmt_cln,&lmt.origin) != EXIT_SUCCESS) lmt.origin=0.0;
 #endif /* !ENABLE_UDUNITS */
     } /* endif */
     
-    /* for ncra, ncrcat the "calendar" attribute has been read in main() 
-       avoid multiple reads of the calendar att in multifile
-       operations */
+    /* ncra and ncrcat read the "calendar" attribute in main() 
+       Avoid multiple reads of calendar attritbute in multi-file operations */
     if(!rec_dmn_and_mlt_fl_opr){
-      if(cal_sng)
-        lmt.lmt_cal=nco_cln_get_cal_typ(cal_sng); 
-      else
-        lmt.lmt_cal=cal_void;
-    }  
-    if(cal_sng)
-      cal_sng=nco_free(cal_sng);
-    
+      if(cln_sng) lmt.lmt_cln=nco_cln_get_cln_typ(cln_sng); else lmt.lmt_cln=cln_nil;
+    } /* endif */
+    if(cln_sng) cln_sng=(char *)nco_free(cln_sng);
   } /* end rcd */
   
   if((lmt.lmt_typ == lmt_crd_val) || (lmt.lmt_typ == lmt_udu_sng)){
@@ -335,9 +331,6 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     long tmp_idx;
     long dmn_srt=0L;
     
-    /* Get variable ID of coordinate 
-       rcd=nco_inq_varid(nc_id,lmt.nm,&dim.cid); */
-    
     /* Get coordinate type */
     (void)nco_inq_vartype(nc_id,dim.cid,&dim.type);
     
@@ -345,7 +338,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     if(dim.type == NC_BYTE || dim.type == NC_UBYTE || dim.type == NC_CHAR || dim.type == NC_STRING) (void)fprintf(stderr,"\n%s: WARNING Coordinate %s is type %s. Dimension truncation is unpredictable.\n",prg_nm_get(),lmt.nm,nco_typ_sng(dim.type));
     
     /* Allocate enough space to hold coordinate */
-    dim.val.vp=(void *)nco_malloc(dmn_sz*nco_typ_lng(dim.type));
+    dmn_val_dp=(double *)nco_malloc(dmn_sz*nco_typ_lng(NC_DOUBLE));
     
 #ifdef _OPENMP
 #pragma omp critical
@@ -353,49 +346,13 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     { /* begin OpenMP critical */
       /* Block is critical for identical in_id's
 	 Block is thread-safe for distinct in_id's */
+      /* 20110221: replace nco_get_vara() with nc_get_vara_double() */
       /* Retrieve this coordinate */
-      nco_get_vara(nc_id,dim.cid,&dmn_srt,&dmn_sz,dim.val.vp,dim.type);
+      nc_get_vara_double(nc_id,dim.cid,(const size_t *)&dmn_srt,(const size_t *)&dmn_sz,dmn_val_dp);
     } /* end OpenMP critical */
     
-    /* Convert coordinate to double-precision if neccessary */
-    if(dim.type != NC_DOUBLE){
-      ptr_unn old_val;
-      
-      old_val=dim.val;
-      dim.val.vp=(void *)nco_malloc(dmn_sz*nco_typ_lng(NC_DOUBLE));
-      /* Typecast old coordinate pointer union to correct type before access */
-      (void)cast_void_nctype(dim.type,&old_val);
-      
-      /* Shortcut to avoid indirection */
-      dmn_val_dp=dim.val.dp;
-      switch(dim.type){
-      case NC_FLOAT: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.fp[idx];} break; 
-      case NC_DOUBLE: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.dp[idx];} break; 
-      case NC_INT: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.ip[idx];} break;
-      case NC_SHORT: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.sp[idx];} break;
-      case NC_USHORT: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.usp[idx];} break;
-      case NC_UINT: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.uip[idx];} break;
-      case NC_INT64: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.i64p[idx];} break;
-      case NC_UINT64: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.ui64p[idx];} break;
-      case NC_BYTE: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.bp[idx];} break;
-      case NC_UBYTE: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.ubp[idx];} break;
-      case NC_CHAR: for(idx=0L;idx<dmn_sz;idx++) {dmn_val_dp[idx]=old_val.cp[idx];} break;
-      case NC_STRING: break; /* Do nothing */
-      default: nco_dfl_case_nc_type_err(); break;
-      } /* end switch */
-      
-      /* Un-typecast pointer to values after access */
-      (void)cast_nctype_void(dim.type,&old_val);
-      
-      /* Free original space allocated for dimension */
-      old_val.vp=nco_free(old_val.vp);
-      
-      /* Officially change type */
-      dim.type=NC_DOUBLE;
-    } /* end type conversion */
-    
-    /* Shortcut to avoid indirection */
-    dmn_val_dp=dim.val.dp;
+    /* Officially change type */
+    dim.type=NC_DOUBLE;
     
     /* Assuming coordinate is monotonic, direction of monotonicity is determined by first two elements */
     if(dmn_sz == 1){
@@ -416,13 +373,12 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     dmn_min=dmn_val_dp[min_idx];
     dmn_max=dmn_val_dp[max_idx];
     
-    /* set defaults */  
+    /* Set defaults */  
     lmt.min_val=dmn_val_dp[min_idx]; 
     lmt.max_val=dmn_val_dp[max_idx];
     
     /* Convert UDUnits strings if necessary */
-    /* If we are here then either min_sng is set or max_sng is set or both set */  
-    
+    /* If we are here then either min_sng or max_sng or both are set */
     if(lmt.lmt_typ == lmt_udu_sng){
       
       if(!fl_udu_sng){ 
@@ -430,24 +386,26 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
         nco_exit(EXIT_FAILURE);
       } /* end if */
       
-      if(lmt.min_sng && nco_cln_clc_org(lmt.min_sng,fl_udu_sng,lmt.lmt_cal,&lmt.min_val)) nco_exit(EXIT_FAILURE);
+      if(lmt.min_sng && nco_cln_clc_org(lmt.min_sng,fl_udu_sng,lmt.lmt_cln,&lmt.min_val)) nco_exit(EXIT_FAILURE);
       
-      if(lmt.max_sng && nco_cln_clc_org(lmt.max_sng,fl_udu_sng,lmt.lmt_cal,&lmt.max_val)) nco_exit(EXIT_FAILURE);
+      if(lmt.max_sng && nco_cln_clc_org(lmt.max_sng,fl_udu_sng,lmt.lmt_cln,&lmt.max_val)) nco_exit(EXIT_FAILURE);
       
     }else{ /* end UDUnits conversion */
       /* Convert user-specified limits into double precision numeric values, or supply defaults */
-      if(lmt.min_sng) lmt.min_val=strtod(lmt.min_sng,(char **)NULL);
-      if(lmt.max_sng) lmt.max_val=strtod(lmt.max_sng,(char **)NULL);
+      if(lmt.min_sng) lmt.min_val=strtod(lmt.min_sng,&sng_cnv_rcd);
+      if(*sng_cnv_rcd) nco_sng_cnv_err(lmt.min_sng,"strtod",sng_cnv_rcd);
+      if(lmt.max_sng) lmt.max_val=strtod(lmt.max_sng,&sng_cnv_rcd);
+      if(*sng_cnv_rcd) nco_sng_cnv_err(lmt.max_sng,"strtod",sng_cnv_rcd);
       
-      /* re-base co-ordinates as necessary in multi-file operatators 
-         lmt.origin has been calculated earlier in file */
+      /* Re-base co-ordinates as necessary in multi-file operatators (MFOs)
+         lmt.origin was calculated earlier in routine */
       if(rec_dmn_and_mlt_fl_opr){ 
         if(lmt.min_sng) lmt.min_val-=lmt.origin;
         if(lmt.max_sng) lmt.max_val-=lmt.origin;   
-      }  
-    }
+      }  /* endif MFO */
+    } /* end UDUnits conversion */
     
-    /* Warn when min_val > max_val (i.e., wrapped coordinate)*/
+    /* Warn when min_val > max_val (i.e., wrapped coordinate) */
     if(dbg_lvl_get() > nco_dbg_std && lmt.min_val > lmt.max_val) (void)fprintf(stderr,"%s: INFO Interpreting hyperslab specifications as wrapped coordinates [%s <= %g] and [%s >= %g]\n",prg_nm_get(),lmt.nm,lmt.max_val,lmt.nm,lmt.min_val);
     
     /* Fail when... */
@@ -459,7 +417,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	  hyperslabs in the record coordinate (i.e., -d time,1.0,1.0) may be
 	  treated differently than single point hyperslabs in other
 	  coordinates. Multifile operators will skip files if single point
-	  hyperslabs in record coordinate lays outside record coordinate
+	  hyperslabs in record coordinate lay outside record coordinate
 	  range of file. For non-record coordinates (and for all operators
 	  besides ncra and ncrcat on record coordinates), single point
 	  hyperslabs will choose the closest value rather than skip the file
@@ -474,7 +432,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       /* Allow for possibility that current file is superfluous */
       if(rec_dmn_and_mlt_fl_opr){
 	flg_no_data=True;
-	goto no_data;
+	goto no_data_ok;
       }else{
 	(void)fprintf(stdout,"%s: ERROR User-specified coordinate value range %g <= %s <= %g does not fall within valid coordinate range %g <= %s <= %g\n",prg_nm_get(),lmt.min_val,lmt.nm,lmt.max_val,dmn_min,lmt.nm,dmn_max);
 	nco_exit(EXIT_FAILURE);
@@ -504,17 +462,16 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       
     }else{ /* min_val != max_val */
       
-      /* Find brackets to specified extrema */
-      /* Should no coordinate values match the given criteria, flag that index with -1L
+      /* Bracket specified extrema:
+	 Should no coordinate values match the given criteria, flag the index with -1L
 	 We defined the valid syntax such that single half range with -1L is not an error
-	 This causes "-d lon,100.0,-100.0" to select [-180.0] when lon=[-180.0,-90.0,0.0,90.0] because one
-	 of the specified half-ranges is valid (there are coordinates < -100.0).
+	 This causes "-d lon,100.0,-100.0" to select [-180.0] when lon=[-180.0,-90.0,0.0,90.0] 
+	 because one of the specified half-ranges is valid (there are coordinates < -100.0).
 	 However, "-d lon,100.0,-200.0" should fail when lon=[-180.0,-90.0,0.0,90.0] because both 
 	 of the specified half-ranges are invalid (no coordinate is > 100.0 or < -200.0).
-	 The -1L flags are replaced with the correct indices (0L or dmn_sz-1L) following the search loop block
-	 Overwriting the -1L flags with 0L or dmn_sz-1L later is more heuristic than setting them = 0L here,
-	 since 0L is valid search result.
-      */
+	 -1L flags are replaced with correct indices (0L or dmn_sz-1L) following search loop block.
+	 Overwriting -1L flags with 0L or dmn_sz-1L later is more heuristic than setting them = 0L here,
+	 since 0L is valid search result. */
       if(monotonic_direction == increasing){
 	if(lmt.min_sng){
 	  /* Find index of smallest coordinate greater than min_val */
@@ -528,6 +485,18 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	  while((dmn_val_dp[tmp_idx] > lmt.max_val) && (tmp_idx > -1L)) tmp_idx--;
 	  if(tmp_idx != -1L) lmt.max_idx=tmp_idx; else lmt.max_idx=-1L;
 	} /* end if */
+	/* 20110221: csz fix hyperslab bug TODO nco1007 triggered by
+	   ncks -O -v lat -d lat,20.,20.001 ~/nco/data/in.nc ~/foo.nc
+	   This returned all values but should have returned none
+	   Algorithm was broken because, although valid min and max indices existed,
+	   they contained the empty set. 
+	   Now when this happens, set flg_no_data_error block */
+	if( /* Points are not wrapped ... */
+	   (lmt.min_val < lmt.max_val) && 
+	   /* ... and valid indices were found for both bracketing points... */
+	   (lmt.min_idx != -1L && lmt.max_idx != -1L) &&
+	   /* ...and indices contain empty set, i.e., min_idx > max_idx for increasing data... */
+   	   lmt.min_idx > lmt.max_idx) flg_no_data_error=True;
 	/* end if monotonic_direction == increasing */
       }else{ /* monotonic_direction == decreasing */
 	if(lmt.min_sng){
@@ -542,6 +511,12 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	  while((dmn_val_dp[tmp_idx] > lmt.max_val) && (tmp_idx < dmn_sz)) tmp_idx++;
 	  if(tmp_idx != dmn_sz) lmt.max_idx=tmp_idx; else lmt.max_idx=-1L;
 	} /* end if */
+	if( /* Points are not wrapped ... */
+	   (lmt.min_val > lmt.max_val) && 
+	   /* ... and valid indices were found for both bracketing points... */
+	   (lmt.min_idx != -1L && lmt.max_idx != -1L) &&
+	   /* ...and indices contain empty set, i.e., min_idx < max_idx for decreasing data... */
+   	   lmt.min_idx < lmt.max_idx) flg_no_data_error=True;
       } /* end else monotonic_direction == decreasing */
       
       /* Case where both min_idx and max_idx = -1 was flagged as error above
@@ -563,30 +538,29 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       lmt.end=lmt.min_idx;
     }  /* end else */
     
-    /* Un-typecast pointer to values after access */
-    (void)cast_nctype_void((nc_type)NC_DOUBLE,&dim.val);
-    
     /* Free space allocated for dimension */
-    dim.val.vp=nco_free(dim.val.vp);
+    dmn_val_dp=nco_free(dmn_val_dp);
     
     if(rec_dmn_and_mlt_fl_opr){ 
       /* No wrapping with multi-file operators */ 
       if((monotonic_direction == increasing && lmt.min_val > lmt.max_val) ||
 	 (monotonic_direction == decreasing && lmt.min_val < lmt.max_val)){
-	flg_no_data=True; goto no_data;   
-      }
+	flg_no_data=True; 
+	goto no_data_ok;   
+      } /* endif */
       
       if(cnt_crr == 0){
-	/* Reset all flags */
+	/* If no valid records yet processed, initialize skipped records to zero */
 	lmt.rec_skp_vld_prv=0L;  
-      }else if(cnt_crr >0L){
-
+      }else if(cnt_crr > 0L){
+	/* Otherwise, account for previous records in strides across file boundaries */
         lmt.srt=lmt.srd-1L-lmt.rec_skp_vld_prv%lmt.srd; 
-
-	if(lmt.srt>lmt.end) 
-         {flg_no_data=True;goto no_data;}
-
-      }
+	if(lmt.srt>lmt.end){
+	  /* Do not allow record dimension wrapping in MFOs */
+	  flg_no_data=True;
+	  goto no_data_ok;
+	} /* endif  */
+      } /* endif */
       
       /* If we are here then there are valid records in current files */ 
        
@@ -606,8 +580,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	 at end of this file (dmn_sz-1L-lmt.end) minus one */
       lmt.rec_skp_vld_prv=dmn_sz-1L-lmt.end;
       /*      assert(lmt.rec_skp_vld_prv >= 0);*/
-    } /* end if rec_muli_file_op */
-    
+    } /* end if rec_dmn_and_mlt_fl_opr */
     
   }else{ /* end if limit arguments were coordinate values */
     /* Convert limit strings to zero-based indicial offsets */
@@ -633,14 +606,16 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       if(FORTRAN_IDX_CNV) lmt.min_idx=1L; else lmt.min_idx=0L;
     }else{
       /* Use user-specified limit when available */
-      lmt.min_idx=strtol(lmt.min_sng,(char **)NULL,10);
+      lmt.min_idx=strtol(lmt.min_sng,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+      if(*sng_cnv_rcd) nco_sng_cnv_err(lmt.min_sng,"strtol",sng_cnv_rcd);
     } /* end if */
     if(lmt.max_sng == NULL || !lmt.is_usr_spc_lmt){
       /* No user-specified value available---generate maximal dimension index */
       if(FORTRAN_IDX_CNV) lmt.max_idx=dmn_sz; else lmt.max_idx=dmn_sz-1L;
     }else{
       /* Use user-specified limit when available */
-      lmt.max_idx=strtol(lmt.max_sng,(char **)NULL,10);
+      lmt.max_idx=strtol(lmt.max_sng,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+      if(*sng_cnv_rcd) nco_sng_cnv_err(lmt.max_sng,"strtol",sng_cnv_rcd);
     } /* end if */
     
     /* Adjust indices if FORTRAN style input was specified */
@@ -667,7 +642,6 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
       lmt.srt=lmt.min_idx;
       lmt.end=lmt.max_idx;
     }else{
-      
       /* Initialize rec_skp_vld_prv to 0L on first call to nco_lmt_evl() 
 	 This is necessary due to intrinsic hysterisis of rec_skp_vld_prv
 	 rec_skp_vld_prv is used only by multi-file operators
@@ -686,17 +660,24 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	   and for ncra and ncrcat (record dimension only) */
 	if(lmt.srd != 1L && prg_id != ncks && !lmt.is_rec_dmn) (void)fprintf(stderr,"%s: WARNING Stride argument for non-record dimension is only supported by ncks, use at your own risk...\n",prg_nm_get());
 	
-	{  
+	{ /* Block to hide scope of local internal variables */
           long min_lcl;
           long max_lcl; 
 	  
-          min_lcl=( lmt.is_usr_spc_min ? lmt.min_idx :0L); 
-          max_lcl=( lmt.is_usr_spc_max ? lmt.max_idx :lmt.rec_skp_nsh_spf+dmn_sz-1L); 
+          min_lcl=(lmt.is_usr_spc_min ? lmt.min_idx : 0L); 
+          max_lcl=(lmt.is_usr_spc_max ? lmt.max_idx : lmt.rec_skp_nsh_spf+dmn_sz-1L); 
 	  
-	  /* see if we are passed max_lcl  */
-          if(max_lcl < lmt.rec_skp_nsh_spf) {flg_no_data=True;goto no_data;} 
-          /* see if min_idx is in current record */
-          if(min_lcl > lmt.rec_skp_nsh_spf+dmn_sz-1L) {flg_no_data=True;goto no_data;}    
+	  /* Are we passed max_lcl? */
+          if(max_lcl < lmt.rec_skp_nsh_spf){
+	    flg_no_data=True;
+	    goto no_data_ok;
+	  } /* endif passed max_lcl */
+
+          /* Is min_idx in current record? */
+          if(min_lcl > lmt.rec_skp_nsh_spf+dmn_sz-1L){
+	    flg_no_data=True;
+	    goto no_data_ok;
+	  } /* endif min_idx in current record */
 	  
 	  if(cnt_crr == 0L)
 	    /* Start index is min_idx adjusted for any skipped initial superfluous files */  
@@ -704,17 +685,19 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
           else
             lmt.srt=lmt.srd-1L-lmt.rec_skp_vld_prv%lmt.srd;
 	  
-          if(lmt.srt >dmn_sz-1L) {flg_no_data=True;goto no_data;}  
+          if(lmt.srt > dmn_sz-1L){
+	    flg_no_data=True;
+	    goto no_data_ok;
+	  } /* endif */
 	  
           lmt.end=(max_lcl < lmt.rec_skp_nsh_spf+dmn_sz) ? max_lcl-lmt.rec_skp_nsh_spf : dmn_sz-1L;
-	  /* integer arithmetic */
+	  /* Integer arithmetic */
 	  cnt_rmn_crr=(lmt.end-lmt.srt)/lmt.srd;
 	  lmt.end=lmt.srt+lmt.srd*cnt_rmn_crr;
-	}
+	} /* end block to hide scope of local internal variables */
 	
-        /* hmb fix 12-2-2010 set stride to one */
-	if(lmt.end==lmt.srt)
-	  lmt.srd=1;
+        /* 20101202: hmb set stride to one */
+	if(lmt.end == lmt.srt) lmt.srd=1;
 	
 	lmt.rec_skp_nsh_spf+=dmn_sz;	
 	/* Compute diagnostic count for this file only */
@@ -724,14 +707,14 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
 	/* rec_skp_vld_prv for next file is stride minus number of unused records
 	   at end of this file (dmn_sz-1L-lmt.end) minus one */
 	lmt.rec_skp_vld_prv=dmn_sz-1L-lmt.end;
-	/*      assert(lmt.rec_skp_vld_prv >= 0);*/
+	/*  assert(lmt.rec_skp_vld_prv >= 0);*/
       
     } /* endif user-specified limits to record dimension */
     
   } /* end else limit arguments are hyperslab indices */
   
   /* Compute cnt from srt, end, and srd
-     This is fine for multi-file record dimensions since those operators read in one
+     This is fine for multi-file record dimensions since those operators read-in one
      record at a time and thus never actually use lmt.cnt for record dimension. */
   if(lmt.srd == 1L){
     if(lmt.srt <= lmt.end) lmt.cnt=lmt.end-lmt.srt+1L; else lmt.cnt=dmn_sz-lmt.srt+lmt.end+1L;
@@ -744,32 +727,37 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
      such that no values are selected in the second read. 
      e.g., "-d lon,60,0,10" if sz(lon)=128 has dmn_cnt_2 == 0
      Since netCDF library reports an error reading and writing cnt=0 dimensions, kludge is necessary
-     Syntax ensures it is always the second read, not the first, which is obviated
+     Syntax ensures that it is always the second read, not the first, which is obviated
      Therefore we convert these degenerate cases into non-wrapped coordinates to be processed by single read 
-     For these degenerate cases only, [srt,end] are not a permutation of [min_idx,max_idx]
-  */
+     For these degenerate cases only, [srt,end] are not a permutation of [min_idx,max_idx] */
   if(
      (lmt.srd != 1L) && /* SRD */
      (lmt.srt > lmt.end) && /* WRP */
      (lmt.cnt == (1L+(dmn_sz-lmt.srt-1L)/lmt.srd)) && /* dmn_cnt_1 == cnt -> dmn_cnt_2 == 0 */
      True){
-    long greatest_srd_multiplier_1st_hyp_slb; /* greatest integer m such that srt+m*srd < dmn_sz */
-    long last_good_idx_1st_hyp_slb; /* C index of last valid member of 1st hyperslab (= srt+m*srd) */
-    /* long left_over_idx_1st_hyp_slb;*/ /* # elements from first hyperslab to count towards current stride */
-    long first_good_idx_2nd_hyp_slb; /* C index of first valid member of 2nd hyperslab, if any */
+    long greatest_srd_multiplier_1st_hyp_slb; /* Greatest integer m such that srt+m*srd < dmn_sz */
+    long last_good_idx_1st_hyp_slb; /* C-index of last valid member of 1st hyperslab (= srt+m*srd) */
+    /* long left_over_idx_1st_hyp_slb;*/ /* # of elements from first hyperslab that count towards current stride */
+    long first_good_idx_2nd_hyp_slb; /* C-index of first valid member of 2nd hyperslab, if any */
     
     /* NB: Perform these operations with integer arithmetic or else! */
     /* Wrapped dimensions with stride may not start at idx 0 on second read */
     greatest_srd_multiplier_1st_hyp_slb=(dmn_sz-lmt.srt-1L)/lmt.srd;
     last_good_idx_1st_hyp_slb=lmt.srt+lmt.srd*greatest_srd_multiplier_1st_hyp_slb;
-    /*    left_over_idx_1st_hyp_slb=dmn_sz-last_good_idx_1st_hyp_slb-1L;*/
+    /* left_over_idx_1st_hyp_slb=dmn_sz-last_good_idx_1st_hyp_slb-1L;*/
     first_good_idx_2nd_hyp_slb=(last_good_idx_1st_hyp_slb+lmt.srd)%dmn_sz;
     
     /* Conditions causing dmn_cnt_2 == 0 */
     if(first_good_idx_2nd_hyp_slb > lmt.end) lmt.end=last_good_idx_1st_hyp_slb;
   } /* end if */
-  
-  /* Exit when valid bracketed range contains no coordinates */
+
+  /* Cases where domain bracketed no data, in error have counts reset to zero here
+     This kludge allows codepaths for both WRP and out-of-domain to flow without goto statements
+     Out-of-domain errors will soon exit with error, while WRP conditions will proceed */
+  if(flg_no_data_error) lmt.cnt=0L;
+
+  /* Exit when valid bracketed range contains no coordinates and that is not legal,
+     i.e., this is not a superfluous file in an MFO */
   if(lmt.cnt == 0){
     if(lmt.lmt_typ == lmt_crd_val) (void)fprintf(stdout,"%s: ERROR Domain %g <= %s <= %g brackets no coordinate values.\n",prg_nm_get(),lmt.min_val,lmt.nm,lmt.max_val); 
     if(lmt.lmt_typ == lmt_dmn_idx) (void)fprintf(stdout,"%s: ERROR Empty domain for %s\n",prg_nm_get(),lmt.nm); 
@@ -778,7 +766,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
   
   /* Coordinate-valued limits that bracket no values in current file jump here with goto
      Index-valued limits with no values in current file flow here naturally */
- no_data: /* end goto */
+ no_data_ok: /* end goto */
   if(flg_no_data){
     /* File is superfluous (contributes no data) to specified hyperslab
        Set output parameters to well-defined state
@@ -797,7 +785,6 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     lmt.rec_skp_vld_prv+=dmn_sz;  
     /* Set variables to preserve utility of diagnostic routines at end of routine */
     cnt_rmn_crr=rec_skp_vld_prv_dgn=0L;
-    
   } /* endif */
   
   /* Place contents of working structure in location of returned structure */
@@ -806,7 +793,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
   if(dbg_lvl_get() >= nco_dbg_io){
     (void)fprintf(stderr,"Dimension hyperslabber nco_lmt_evl() diagnostics:\n");
     (void)fprintf(stderr,"Dimension name = %s\n",lmt.nm);
-    (void)fprintf(stderr,"Limit type is %s\n",(min_lmt_typ == lmt_crd_val) ? "coordinate value" : "zero-based dimension index");
+    (void)fprintf(stderr,"Limit type is %s\n",(min_lmt_typ == lmt_crd_val) ? "coordinate value" : (FORTRAN_IDX_CNV) ? "one-based dimension index" : "zero-based dimension index");
     (void)fprintf(stderr,"Limit %s user-specified\n",(lmt.is_usr_spc_lmt) ? "is" : "is not");
     (void)fprintf(stderr,"Limit %s record dimension\n",(lmt.is_rec_dmn) ? "is" : "is not");
     (void)fprintf(stderr,"Current file %s specified hyperslab, data %s be read\n",(flg_no_data) ? "is superfluous to" : "is required by",(flg_no_data) ? "will not" : "will");
@@ -819,6 +806,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     (void)fprintf(stderr,"min_sng = %s\n",lmt.min_sng == NULL ? "NULL" : lmt.min_sng);
     (void)fprintf(stderr,"max_sng = %s\n",lmt.max_sng == NULL ? "NULL" : lmt.max_sng);
     (void)fprintf(stderr,"srd_sng = %s\n",lmt.srd_sng == NULL ? "NULL" : lmt.srd_sng);
+    (void)fprintf(stderr,"monotonic_direction = %s\n",monotonic_direction == increasing ? "increasing" : "decreasing");
     (void)fprintf(stderr,"min_val = %g\n",lmt.min_val);
     (void)fprintf(stderr,"max_val = %g\n",lmt.max_val);
     (void)fprintf(stderr,"min_idx = %li\n",lmt.min_idx);
@@ -826,7 +814,10 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     (void)fprintf(stderr,"srt = %li\n",lmt.srt);
     (void)fprintf(stderr,"end = %li\n",lmt.end);
     (void)fprintf(stderr,"cnt = %li\n",lmt.cnt);
-    (void)fprintf(stderr,"srd = %li\n\n",lmt.srd);
+    (void)fprintf(stderr,"srd = %li\n",lmt.srd);
+    (void)fprintf(stderr,"WRP = %s\n",lmt.srt > lmt.end ? "YES" : "NO");
+    (void)fprintf(stderr,"SRD = %s\n",lmt.srd != 1L ? "YES" : "NO");
+    (void)fprintf(stderr,"no_data = %s\n\n",flg_no_data ? "True" : "False");
   } /* end dbg */
   
   if(lmt.srt > lmt.end && !flg_no_data){
@@ -834,7 +825,7 @@ nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications *
     if(prg_id != ncks) (void)fprintf(stderr,"HINT: If operation fails, try multislabbing (http://nco.sf.net/nco.html#msa) wrapped dimension using ncks first, and then apply %s to the resulting file\n",prg_nm_get());
   } /* end dbg */
   
-  (void*)nco_free(fl_udu_sng);
+  fl_udu_sng=(char *)nco_free(fl_udu_sng);
   
 } /* end nco_lmt_evl() */
 
@@ -895,7 +886,7 @@ nco_lmt_prs /* [fnc] Create limit structures with name, min_sng, max_sng element
     /* rec_skp_nsh_spf is used for record dimension in multi-file operators */
     lmt[idx]->rec_skp_nsh_spf=0L; /* Number of records skipped in initial superfluous files */
     
-    /* Fill in structure */
+    /* Fill-in structure */
     lmt[idx]->nm=arg_lst[0];
     lmt[idx]->min_sng=arg_lst[1];
     /* Setting min_sng and max_sng to same pointer would lead to dangerous double-free() condition */
@@ -908,21 +899,17 @@ nco_lmt_prs /* [fnc] Create limit structures with name, min_sng, max_sng element
     
     /* Initialize types used to re-base coordinate variables */
     lmt[idx]->origin=0.0;
-    lmt[idx]->re_bs_sng=NULL_CEWI;
-    lmt[idx]->lmt_cal=cal_void;
+    lmt[idx]->rbs_sng=NULL_CEWI;
+    lmt[idx]->lmt_cln=cln_nil;
     
-    /* Free current pointer array to strings
-       Strings themselves are untouched 
+    /* Free current pointer array to strings, leaving untouched the strings themselves
        They will be free()'d with limit structures in nco_lmt_lst_free() */
     arg_lst=(char **)nco_free(arg_lst);
-    
   } /* End loop over lmt structure list */
   
   return lmt;
-  
 } /* end nco_lmt_prs() */
 
-
 int /* O [enm] Limit type */
 nco_lmt_typ /* [fnc] Determine limit type */
 (char *sng) /* I [ptr] Pointer to limit string */
