@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_mpi.h,v 1.16 2010/01/05 20:02:18 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_mpi.h,v 1.19 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: MPI utilities */
 
@@ -13,7 +13,7 @@
    I am not yet sure I want _any_ MPI dependencies in libnco.a 
    Cross-platform link weirdness (e.g., AIX) makes avoiding this desirable */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -72,7 +72,9 @@ extern "C" {
 
   const int nco_spn_lck_us=100; /* [us] Spinlock sleep interval */
   int nco_spn_lck_brk=0; /* [nbr] Break spin lock, resume execution */
-  void nco_cnt_run(int signo){nco_spn_lck_brk=1;} /* Signal handler */
+
+  void nco_cnt_run(int signo); /* Signal handler */
+  void nco_cnt_run(int signo){nco_spn_lck_brk=1+0*signo;} /* Signal handler, CEWI */
 
 #ifdef __cplusplus
 } /* end extern "C" */
