@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.78 2010/03/12 07:08:15 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_msa.c,v 1.85 2011/02/21 22:38:42 zender Exp $ */
 
 /* Purpose: Multi-slabbing algorithm */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -68,17 +68,14 @@ nco_msa_rec_clc /* [fnc] Multi-slab algorithm (recursive routine, returns a sing
       cp_sz[idx]=vara->sz;
     } /* end loop over idx */
     
-    for(idx=0;idx<dpt_crr_max;idx++) 
-      var_sz*=(idx<dpt_crr ? lmt[idx]->cnt : lmt_lst[idx]->dmn_cnt);
+    for(idx=0;idx<dpt_crr_max;idx++) var_sz*=(idx<dpt_crr ? lmt[idx]->cnt : lmt_lst[idx]->dmn_cnt);
     
     vp=(void *)nco_calloc((size_t)var_sz,nco_typ_lng(vara->type));
     
     lcnt=nco_typ_lng(vara->type);
-    for(idx=dpt_crr+1;idx<dpt_crr_max;idx++) 
-      lcnt*=lmt_lst[idx]->dmn_cnt;
+    for(idx=dpt_crr+1;idx<dpt_crr_max;idx++) lcnt*=lmt_lst[idx]->dmn_cnt;
     
     cp_inc=(ptrdiff_t)(lcnt*lmt_lst[dpt_crr]->dmn_cnt);
-    
     cp_max=(ptrdiff_t)(var_sz*nco_typ_lng(vara->type));
     
     for(idx=0;idx<nbr_slb;idx++) indices[idx]=lmt_lst[dpt_crr]->lmt_dmn[idx]->srt;
@@ -86,7 +83,7 @@ nco_msa_rec_clc /* [fnc] Multi-slab algorithm (recursive routine, returns a sing
     cp_fst=0L;
     
     /* Deal first with wrapped dimensions
-       True if wrapped dims or slabs DONT Overlap or user specified order */
+       True if wrapped dims or slabs DO NOT overlap or user-specified order */
     if(lmt_lst[dpt_crr]->WRP || lmt_lst[dpt_crr]->MSA_USR_RDR){
       
       for(slb_idx=0;slb_idx<nbr_slb;slb_idx++){
@@ -536,7 +533,7 @@ nco_msa_min_idx /* [fnc] Find minimum values in current and return minimum value
 } /* end nco_msa_min_idx() */
 
 void
-nco_msa_var_get    /* [fnc] Get var data from disk taking accound of multihyperslabs */
+nco_msa_var_get    /* [fnc] Get variable data from disk taking account of multihyperslabs */
 (const int in_id,  /* I [id] netCDF input file ID */
  var_sct *var_in,
  lmt_all_sct * const * lmt_lst, /* I multi-hyperslab limits */
@@ -552,9 +549,9 @@ lmt_sct **lmt;
 
   nbr_dim=var_in->nbr_dim;	
 
-  // Refresh nc_id with in_id, NB: makes OpenMP threading work
-  // Should have been included in release 3.9.5
-  // Fixes TODO nco956
+  /* Refresh nc_id with in_id, NB: makes OpenMP threading work
+     Should have been included in release 3.9.5
+     Fixes TODO nco956 */
   var_in->nc_id=in_id; 
   /* Deal with scalar var */
   if(nbr_dim==0){
@@ -567,10 +564,10 @@ lmt_sct **lmt;
   lmt_mult=(lmt_all_sct **)nco_malloc(nbr_dim*sizeof(lmt_all_sct *));
   lmt=(lmt_sct **)nco_malloc(nbr_dim*sizeof(lmt_sct *));
 
-/* Initialize lmt_mult with multi-limits from lmt_lst limits */
+  /* Initialize lmt_mult with multi-limits from lmt_lst limits */
   for(idx=0;idx<nbr_dim;idx++){
     for(jdx=0;jdx<nbr_dmn_fl;jdx++){
-      if(!strcmp(var_in->dim[idx]->nm,lmt_lst[jdx]->dmn_nm ) ){
+      if(!strcmp(var_in->dim[idx]->nm,lmt_lst[jdx]->dmn_nm)){
 	lmt_mult[idx]=lmt_lst[jdx];
         break;
       } /* end if */
@@ -840,7 +837,7 @@ nco_msa_prn_var_val   /* [fnc] Print variable data */
   /* Call also initializes var.sz with final size */
 
   /* Warn if variable is packed */
-  if(nco_pck_dsk_inq(in_id,&var)) (void)fprintf(stderr,"%s: WARNING about to print packed contents of packed variable \"%s\". Consider unpacking it first using ncpdq -U.\n",prg_nm_get(),var_nm);
+  if(nco_pck_dsk_inq(in_id,&var)) (void)fprintf(stderr,"%s: WARNING about to print packed contents of variable \"%s\". Consider unpacking variable first using ncpdq -U.\n",prg_nm_get(),var_nm);
   
   /* User supplied dlm_sng, print var (includes nbr_dmn == 0) */  
   if(dlm_sng){
@@ -1205,7 +1202,7 @@ nco_msa_prn_var_val   /* [fnc] Print variable data */
   
 } /* end nco_msa_prn_var_val() */
 
-void         /* Initilaize lmt_all_sct's */ 
+void /* Initilaize lmt_all_sct's */ 
 nco_msa_lmt_all_int
 (int in_id,
  nco_bool MSA_USR_RDR,
@@ -1225,9 +1222,6 @@ nco_msa_lmt_all_int
   
   (void)nco_inq(in_id,(int*)NULL,(int*)NULL,(int *)NULL,&rec_dmn_id);
   
-  /* Unlimited dimensions are stored in */
-  // lmt_rgl=(lmt_sct **)nco_malloc(nbr_dmn_fl*sizeof(lmt_sct*));
-  
   for(idx=0;idx<nbr_dmn_fl;idx++){
     (void)nco_inq_dim(in_id,idx,dmn_nm,&dmn_sz);
     lmt_all_crr=lmt_all_lst[idx]=(lmt_all_sct *)nco_malloc(sizeof(lmt_all_sct));
@@ -1255,8 +1249,9 @@ nco_msa_lmt_all_int
     lmt_rgl->min_sng=NULL;
     lmt_rgl->max_sng=NULL;
     lmt_rgl->srd_sng=NULL;
-    lmt_rgl->re_bs_sng=NULL;
+    lmt_rgl->rbs_sng=NULL;
     lmt_rgl->origin=0.0;
+
     /* A hack so we know structure has been initialized */
     lmt_rgl->lmt_typ=-1;
   } /* end loop over dimensions */
@@ -1264,12 +1259,12 @@ nco_msa_lmt_all_int
   /* fxm: subroutine-ize this MSA code block for portability TODO nco926 */
   /* Add user specified limits lmt_all_lst */
   for(idx=0;idx<lmt_nbr;idx++){
-    for(jdx=0;jdx<nbr_dmn_fl;jdx++) {
+    for(jdx=0;jdx<nbr_dmn_fl;jdx++){
       if(!strcmp(lmt[idx]->nm,lmt_all_lst[jdx]->dmn_nm)){   
 	lmt_all_crr=lmt_all_lst[jdx];
 	lmt_all_crr->BASIC_DMN=False;
 	if(lmt_all_crr->lmt_dmn[0]->lmt_typ == -1) { 
-          /* free defualt limit set above structure first */
+          /* Free defualt limit set above structure first */
           lmt_all_crr->lmt_dmn[0]=(lmt_sct*)nco_lmt_free(lmt_all_crr->lmt_dmn[0]);
 	  lmt_all_crr->lmt_dmn[0]=lmt[idx]; 
 	}else{ 
@@ -1288,12 +1283,11 @@ nco_msa_lmt_all_int
   
   /* fxm: subroutine-ize this MSA code block for portability TODO nco926 */
   for(idx=0;idx<nbr_dmn_fl;idx++){
-    nco_bool bovl;
+    nco_bool flg_ovl;
     
-	/* nb progs ncra/ncrcat only one limit for the record dimension so skip evaluation*/
-	/* otherwise this messes up multi-file operation */
-	if(lmt_all_lst[idx]->lmt_dmn[0]->is_rec_dmn && (prg_get()==ncra || prg_get()==ncrcat))
-	  continue;
+    /* NB: ncra/ncrcat have only one limit for record dimension so skip 
+       evaluation otherwise this messes up multi-file operation */
+    if(lmt_all_lst[idx]->lmt_dmn[0]->is_rec_dmn && (prg_get() == ncra || prg_get() == ncrcat)) continue;
 	
     /* Split-up wrapped limits */   
     (void)nco_msa_wrp_splt(lmt_all_lst[idx]);
@@ -1323,13 +1317,13 @@ nco_msa_lmt_all_int
     /* Sort limits */
     (void)nco_msa_qsort_srt(lmt_all_lst[idx]);
     /* Check for overlap */
-    bovl=nco_msa_ovl(lmt_all_lst[idx]);  
-    if(bovl==False) lmt_all_lst[idx]->MSA_USR_RDR=True;
+    flg_ovl=nco_msa_ovl(lmt_all_lst[idx]);  
+    if(flg_ovl==False) lmt_all_lst[idx]->MSA_USR_RDR=True;
     
     /* Find and store size of output dimension */  
     (void)nco_msa_clc_cnt(lmt_all_lst[idx]);       
-    if(dbg_lvl_get() >1 ) {
-      if(bovl) (void)fprintf(stdout,"%s: dimension \"%s\" has overlapping hyperslabs\n",prg_nm_get(),lmt_all_lst[idx]->dmn_nm); else (void)fprintf(stdout,"%s: dimension \"%s\" has distinct hyperslabs\n",prg_nm_get(),lmt_all_lst[idx]->dmn_nm); 
+    if(dbg_lvl_get() > 1){
+      if(flg_ovl) (void)fprintf(stdout,"%s: dimension \"%s\" has overlapping hyperslabs\n",prg_nm_get(),lmt_all_lst[idx]->dmn_nm); else (void)fprintf(stdout,"%s: dimension \"%s\" has distinct hyperslabs\n",prg_nm_get(),lmt_all_lst[idx]->dmn_nm); 
     } /* endif */
     
   } /* end idx */    
@@ -1353,61 +1347,59 @@ nco_msa_var_val_cpy /* [fnc] Copy variables data from input to output file */
   int jdx;
   int kdx;
   int nbr_dim;
-  /* int dmn_idx; */
-  /* long srd_prd=1L; */ /* [nbr] Product of strides */
+  int dmn_idx; 
+  long srd_prd=1L;  /* [nbr] Product of strides */
   
   for(idx=0;idx<nbr_var;idx++){
 
     nbr_dim=var[idx]->nbr_dim;
 
-  /* GET VARIABLE DATA */
+    /* GET VARIABLE DATA */
   
-  /* Deal with scalar var */
-  if(nbr_dim==0){
-   var[idx]->val.vp=nco_malloc(nco_typ_lng(var[idx]->type));
-   (void)nco_get_var1(in_id,var[idx]->id,0L,var[idx]->val.vp,var[idx]->type);
-  }else{
-    lmt_all_sct **lmt_mult;
-	lmt_sct **lmt;
-
-    lmt_mult=(lmt_all_sct **)nco_malloc(nbr_dim*sizeof(lmt_all_sct *));
-    lmt=(lmt_sct **)nco_malloc(nbr_dim*sizeof(lmt_sct *));
-
-    /* Initialize lmt_mult with multi-limits from lmt_lst limits */
-    for(jdx=0;jdx<nbr_dim;jdx++){
-      for(kdx=0;kdx<nbr_dmn_fl;kdx++){
-      if(!strcmp(var[idx]->dim[jdx]->nm,lmt_lst[kdx]->dmn_nm ) ){
-	   lmt_mult[jdx]=lmt_lst[kdx];
-        break;
-       } /* end if */
-      } /* end loop over jdx */
-    } /* end idx */
+    /* Deal with scalar var */
+    if(nbr_dim==0){
+      var[idx]->val.vp=nco_malloc(nco_typ_lng(var[idx]->type));
+      (void)nco_get_var1(in_id,var[idx]->id,0L,var[idx]->val.vp,var[idx]->type);
+    }else{
+      lmt_all_sct **lmt_mult;
+      lmt_sct **lmt;
+      
+      lmt_mult=(lmt_all_sct **)nco_malloc(nbr_dim*sizeof(lmt_all_sct *));
+      lmt=(lmt_sct **)nco_malloc(nbr_dim*sizeof(lmt_sct *));
+      
+      /* Initialize lmt_mult with multi-limits from lmt_lst limits */
+      for(jdx=0;jdx<nbr_dim;jdx++){
+	for(kdx=0;kdx<nbr_dmn_fl;kdx++){
+	  if(!strcmp(var[idx]->dim[jdx]->nm,lmt_lst[kdx]->dmn_nm ) ){
+	    lmt_mult[jdx]=lmt_lst[kdx];
+	    break;
+	  } /* end if */
+	} /* end loop over jdx */
+      } /* end idx */
+      
+      /* Call super-dooper recursive routine */
+      /* NB: nco_msa_rec_clc() with same nc_id contains OpenMP critical region */
+      var[idx]->val.vp=nco_msa_rec_clc(0,nbr_dim,lmt,lmt_mult,var[idx]);
   
-    /* Call super-dooper recursive routine */
-    /* NB: nco_msa_rec_clc() with same nc_id contains OpenMP critical region */
-    var[idx]->val.vp=nco_msa_rec_clc(0,nbr_dim,lmt,lmt_mult,var[idx]);
-  
-    (void)nco_free(lmt_mult);
-    (void)nco_free(lmt);
-   } /* end else nbr_dim */
+      (void)nco_free(lmt_mult);
+      (void)nco_free(lmt);
+    } /* end else nbr_dim */
       
     /*(void)nco_msa_var_get(in_id,var[idx],lmt_lst,nbr_dmn_fl); */  
   
-	/* PUT VARIABLE DATA */
+    /* PUT VARIABLE DATA */
 	  		  
     if(var[idx]->nbr_dim == 0)
       nco_put_var1(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->val.vp,var[idx]->type);
     else{ /* end if variable is scalar */
       if(var[idx]->sz > 0){ /* Do nothing for zero-size record variables */
 	/* Is stride > 1? */
-        /*
 	for(dmn_idx=0;dmn_idx<var[idx]->nbr_dim;dmn_idx++) srd_prd*=var[idx]->srd[dmn_idx];
 
 	if(srd_prd == 1L)
 	  nco_put_vara(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->val.vp,var[idx]->type);
 	else
-        */
-	  (void)nco_put_varm(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->xrf->srd,(long *)NULL,var[idx]->val.vp,var[idx]->type);
+	  nco_put_varm(out_id,var[idx]->xrf->id,var[idx]->xrf->srt,var[idx]->xrf->cnt,var[idx]->xrf->srd,(long *)NULL,var[idx]->val.vp,var[idx]->type);
 	
       } /* end if var_sz */
     } /* end if variable is an array */
@@ -1415,9 +1407,3 @@ nco_msa_var_val_cpy /* [fnc] Copy variables data from input to output file */
   } /* end loop over idx */
     
 } /* end nco_msa_var_val_cpy() */
-
-
-
-
-
-
