@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.c,v 1.128 2010/01/05 21:25:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.c,v 1.137 2011/02/21 23:38:00 zender Exp $ */
 
 /* Purpose: NCO wrappers for netCDF C library */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -95,7 +95,7 @@ nco_err_exit /* [fnc] Print netCDF error message, routine name, then exit */
      Only attempt to print netCDF error messages when rcd != 0 */
   (void)fprintf(stderr,"%s: ERROR Error code is %d. ",fnc_nm,rcd);
   if(rcd == NC_NOERR){
-    (void)fprintf(stderr,"This indicates an inconvenient truth in the NCO code (not in the netCDF layer)\n");
+    (void)fprintf(stderr,"This indicates an error occurred outside of the netCDF layer, i.e., in NCO code or in a system call.\n");
   }else{
     (void)fprintf(stderr,"Translation into English with nc_strerror(%d) is \"%s\"\n",rcd,nc_strerror(rcd));
   } /* !NC_NOERR */
@@ -105,7 +105,7 @@ nco_err_exit /* [fnc] Print netCDF error message, routine name, then exit */
 #ifdef NCO_ABORT_ON_ERROR
   /* abort() produces core dump and traceback information
      Most debuggers (e.g., gdb) use this information to print the calling tree that produced the abort()
-     This makes debugging much easier!
+     This makes debugging much easier.
      Hence we recommend developers compile NCO with -DNCO_ABORT_ON_ERROR */
   abort();
 #else /* !NCO_ABORT_ON_ERROR */
@@ -132,7 +132,7 @@ nco_typ_lng /* [fnc] Convert netCDF type enum to native type size */
   case NC_INT:
     return sizeof(nco_int);
   case NC_SHORT:
-    return sizeof(short);
+    return sizeof(short int);
   case NC_CHAR:
     return sizeof(nco_char);
   case NC_BYTE:
@@ -351,6 +351,28 @@ nco_dfl_case_nc_type_err(void) /* [fnc] Print error and exit for illegal switch(
   nco_err_exit(0,fnc_nm);
 } /* end nco_dfl_case_nc_type_err() */
 
+void
+nco_sng_cnv_err /* [fnc] Print error and exit for failed strtol()-type calls */
+(const char *cnv_sng, /* I [sng] String to convert */
+ const char *sng_cnv_fnc, /* I [sng] Name of function used to convert string */
+ const char *err_ptr) /* I [chr] First illegal character in string */
+{
+  /* Purpose: Convenience routine for printing error and exiting when
+     strtol()/strtoul()/strtoll()/strtoull() receives illegal characters.
+     Placing this in its own routine saves many lines of error handling. */
+  const char fnc_nm[]="nco_sng_cnv_err()";
+  if(!strcmp(sng_cnv_fnc,"strtod")){
+    /* Handle conversion errors for strtod()... */
+    (void)fprintf(stdout,"%s: ERROR an NCO function or main program attempted to convert the (probably user-defined) string \"%s\" to a floating point type using the standard C-library function \"%s()\". This function stopped converting the input string when it encountered the illegal (i.e., non-numeric) character \'%c\'. This probably indicates a syntax error by the user. Please check the argument syntax and re-try the command. ",fnc_nm,cnv_sng,sng_cnv_fnc,err_ptr[0]);
+  }else{ /* !strtod() */
+    /* Handle conversion errors for strtol(), strtoul()... */
+    (void)fprintf(stdout,"%s: ERROR an NCO function or main program attempted to convert the user-defined string \"%s\" to an integer-type using the standard C-library function \"%s()\". This function stopped converting the input string when it encountered the illegal (i.e., non-numeric or non-integer) character \'%c\'. This probably indicates a syntax error by the user. Please check the argument syntax and re-try the command. ",fnc_nm,cnv_sng,sng_cnv_fnc,err_ptr[0]);
+  } /* !strtod() */
+  if(err_ptr[0] == ',') (void)fprintf(stdout,"HINT: Conversion functions like \"%s()\" accept only one number at a time, so comma-separated lists of numbers are invalid. ",sng_cnv_fnc);
+  (void)fprintf(stdout,"Exiting...\n");
+  nco_err_exit(0,fnc_nm);
+} /* end nco_sng_cnv_err() */
+
 void
 nco_dfl_case_prg_id_err(void) /* [fnc] Print error and exit for illegal switch(prg_id) case */
 {
@@ -803,6 +825,64 @@ nco_inq_var_fletcher32
   return rcd;
 } /* end nco_inq_var_fletcher32() */
 
+int /* O [flg] Return success code */
+nco_inq_var_packing /* [fnc] Check whether variable is packed on disk */
+(const int nc_id, /* I [ID] netCDF ID */
+ const int var_id, /* I [ID] Variable ID */
+ int * const packing) /* O [flg] Variable is packed on disk */
+{
+  /* Purpose: Check whether variable is packed on disk
+     Designed to behave like netCDF-library call for packing (which does not exist)
+     Based on nco_pck_dsk_inq()
+     Difference is that:
+     nco_pck_dsk_inq() fills in members of variable structure
+     nco_inq_var_packing() does not need a variable structure, or anything from nco.h
+     Hence, nco_inq_var_packing is suitable for light-overhead calls, such as by ncks for printing */ 
+  
+  const char add_fst_sng[]="add_offset"; /* [sng] Unidata standard string for add offset */
+  const char scl_fct_sng[]="scale_factor"; /* [sng] Unidata standard string for scale factor */
+  
+  int rcd; /* [rcd] Return success code */
+  int has_scl_fct; /* [flg] Valid scale_factor attribute exists */
+  int has_add_fst; /* [flg] Valid add_offset attribute exists */
+  
+  long add_fst_lng; /* [idx] Number of elements in add_offset attribute */
+  long scl_fct_lng; /* [idx] Number of elements in scale_factor attribute */
+
+  nc_type add_fst_typ; /* [idx] Type of add_offset attribute */
+  nc_type scl_fct_typ; /* [idx] Type of scale_factor attribute */
+
+  /* Initialize and default to most-likely outcome, that variable is not packed */
+  has_scl_fct=0; /* [flg] Valid scale_factor attribute exists */
+  has_add_fst=0; /* [flg] Valid add_offset attribute exists */
+  *packing=0; /* [flg] Variable is packed on disk */
+
+  /* Vet scale_factor */
+  rcd=nco_inq_att_flg(nc_id,var_id,scl_fct_sng,&scl_fct_typ,&scl_fct_lng);
+  if(rcd != NC_ENOTATT){
+    if(scl_fct_typ == NC_BYTE || scl_fct_typ == NC_CHAR) return NC_NOERR;
+    if(scl_fct_lng != 1) return NC_NOERR;
+    has_scl_fct=1; /* [flg] Valid scale_factor attribute exists */
+  } /* endif */
+
+  /* Vet add_offset */
+  rcd=nco_inq_att_flg(nc_id,var_id,add_fst_sng,&add_fst_typ,&add_fst_lng);
+  if(rcd != NC_ENOTATT){
+    if(add_fst_typ == NC_BYTE || add_fst_typ == NC_CHAR) return NC_NOERR;
+    if(add_fst_lng != 1) return NC_NOERR;
+    has_add_fst=1; /* [flg] Valid add_offset attribute exists */
+  } /* endif */
+
+  if(has_scl_fct && has_add_fst)
+    if(scl_fct_typ != add_fst_typ) 
+      return NC_NOERR;
+
+  /* Variable is considered packed iff either or both valid scale_factor or add_offset exist */
+  if(has_scl_fct || has_add_fst) *packing=1; /* [flg] Variable is packed on disk */
+
+  return NC_NOERR;
+} /* end nco_inq_var_packing() */
+
 int
 nco_inq_varid(const int nc_id,const char * const var_nm,int * const var_id)
 {
