@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.70 2010/01/05 21:16:20 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_netcdf.h,v 1.74 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: NCO wrappers for netCDF C library */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -15,6 +15,7 @@
 /* Standard header files */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
+#include <string.h> /* strcmp. . . */
 
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
@@ -53,6 +54,13 @@ void
 nco_dfl_case_prg_id_err /* [fnc] Print error and exit for illegal switch(prg_id) case */
 (void);
 
+void
+nco_sng_cnv_err /* [fnc] Print error and exit for failed strtol()-type calls */
+(const char *cnv_sng, /* I [sng] String to convert */
+ const char *sng_cnv_fnc, /* I [sng] Name of function used to convert string */
+ const char *err_ptr); /* I [chr] First illegal character in string */
+/* end nco_sng_cnv_err() */
+
 void 
 nco_err_exit /* [fnc] Print netCDF error message, routine name, then exit */
 (const int rcd, /* I [enm] netCDF error code */ 
@@ -125,6 +133,7 @@ int nco_inq_var(const int nc_id,const int var_id,char * const var_nm,nc_type * c
 int nco_inq_var_chunking(const int nc_id,const int var_id,int * const srg_typ,size_t * const cnk_sz);
 int nco_inq_var_deflate(const int nc_id,const int var_id,int * const shuffle,int * const deflate,int * const dfl_lvl);
 int nco_inq_var_fletcher32(const int nc_id,const int var_id,int * const chk_typ);
+int nco_inq_var_packing(const int nc_id,const int var_id,int * const packing);
 int nco_inq_vardimid(const int nc_id,const int var_id,int * const dmn_id);
 int nco_inq_varid(const int nc_id,const char * const var_nm,int * const var_id);
 int nco_inq_varid_flg(const int nc_id,const char * const var_nm,int * const var_id);
