@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_pck.c,v 1.78 2010/01/26 13:06:25 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_pck.c,v 1.87 2011/02/12 03:05:20 zender Exp $ */
 
 /* Purpose: NCO utilities for packing and unpacking variables */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -18,7 +18,13 @@
    From netCDF User's Guide:
    scale_factor: If present for a variable, the data are to be multiplied by this factor after the data are read by the application that accesses the data
    add_offset: If present for a variable, this number is added to the data after the data are read by the application. If both scale_factor and add_offset attributes are present, the data are first scaled before the offset is added. 
-   When scale_factor and add_offset are used for packing, the associated variable (containing the packed data) is typically of type byte or short, whereas the unpacked values are intended to be of type float or double. Attribute's scale_factor and add_offset should both be of type intended for the unpacked data, e.g., float or double. */
+   When scale_factor and add_offset are used for packing, the associated variable (containing the packed data) is typically of type byte or short, whereas the unpacked values are intended to be of type float or double. Attribute's scale_factor and add_offset should both be of type intended for the unpacked data, e.g., float or double.
+
+   20101007 Dave Allured says that Unidata says this in NetCDF Best Practices: 
+   "The _FillValue attribute should have the same data type as the variable it describes. If the variable is packed using scale_factor and add_offset attributes, the _FillValue attribute should have the data type of the packed data." 
+   http://www.unidata.ucar.edu/software/netcdf/docs/BestPractices.html#Missing%20Data%20Values 
+
+   CF conventions say about the same thing. If there is a mismatch between the attribute type and the data type, or if an incorrect value was stored in the _FillValue attribute, then manual intervention is needed. However note that storing -999 in an attribute of type short vs. integer is not much of a problem, because the two are are numerically identical. The important question in this case is whether ncra has an automatic method to exclude missing values from being transformed by averaging, in the face of a packed variable. If so, how is it done, or where in the documentation is it described. */
 
 const char * /* O [sng] Packing map string */
 nco_pck_map_sng_get /* [fnc] Convert packing map enum to string */
@@ -390,7 +396,8 @@ nco_pck_dsk_inq /* [fnc] Check whether variable is packed on disk */
      nco_pck_dsk_inq() should be called early in application, e.g., in nco_var_fll() 
      Call nco_pck_dsk_inq() before copying input list to output list 
      Multi-file operators which handle packing must call this routine prior
-     to each read of a variable, in case that variable has been unpacked. */
+     to each read of a variable, in case that variable has been unpacked.
+     NB: See also nco_inq_var_packing(), a light-overhead alternative to nco_pck_dsk_inq() */
   /* ncea -O -D 3 -v pck ~/nco/data/in.nc ~/nco/data/foo.nc */
   
   const char add_fst_sng[]="add_offset"; /* [sng] Unidata standard string for add offset */
@@ -751,6 +758,7 @@ nco_var_pck /* [fnc] Pack variable in memory */
        ndrv = 256*256*256*256 = 2^32 iff var->typ_pck == NC_INT */
 
     const double max_mns_min_dbl_wrn=1.0e10; /* [frc] Threshold value for warning */
+    double mss_val_dbl; /* [ptr] Missing value of variable expressed in double precision */
     double ndrv_dbl=double_CEWI; /* [frc] Double precision value of number of discrete representable values */
     double max_mns_min_dbl; /* [frc] Maximum value minus minimum value */
 
@@ -805,25 +813,77 @@ nco_var_pck /* [fnc] Pack variable in memory */
       if(min_var->val.dp[0] == ptr_unn_mss_val_dbl.dp[0]) 
 	PURE_MSS_VAL_FLD=True;
 
+    /* fxm TODO nco1003 20101129 */
     /* Change value of missing value iff necessary to fit inside packed type */
     if(var->has_mss_val && !PURE_MSS_VAL_FLD){
       double mss_val_dfl_dbl=0.0; /* CEWI */
+      double pck_rng_min_dbl=0.0; /* CEWI */
+      double pck_rng_max_dbl=0.0; /* CEWI */
       switch(nc_typ_pck){ 
-      case NC_FLOAT: mss_val_dfl_dbl=NC_FILL_FLOAT; break; 
-      case NC_DOUBLE: mss_val_dfl_dbl=NC_FILL_DOUBLE; break; 
-      case NC_INT: mss_val_dfl_dbl=NC_FILL_INT; break;
-      case NC_SHORT: mss_val_dfl_dbl=NC_FILL_SHORT; break;
-      case NC_USHORT: mss_val_dfl_dbl=NC_FILL_USHORT; break;
-      case NC_UINT: mss_val_dfl_dbl=NC_FILL_UINT; break;
-      case NC_INT64: mss_val_dfl_dbl=NC_FILL_INT64; break;
-      case NC_UINT64: mss_val_dfl_dbl=NC_FILL_UINT64; break;
-      case NC_BYTE: mss_val_dfl_dbl=NC_FILL_BYTE; break;
-      case NC_UBYTE: mss_val_dfl_dbl=NC_FILL_UBYTE; break;
-      case NC_CHAR: mss_val_dfl_dbl=NC_FILL_CHAR; break;
+      case NC_FLOAT:
+	mss_val_dfl_dbl=NC_FILL_FLOAT; 
+	pck_rng_min_dbl=NC_MIN_FLOAT;
+	pck_rng_max_dbl=NC_MAX_FLOAT;
+	break; 
+      case NC_DOUBLE:
+	mss_val_dfl_dbl=NC_FILL_DOUBLE; 
+	pck_rng_min_dbl=NC_MIN_DOUBLE;
+	pck_rng_max_dbl=NC_MAX_DOUBLE;
+	break; 
+      case NC_INT:
+	mss_val_dfl_dbl=NC_FILL_INT; 
+	pck_rng_min_dbl=NC_MIN_INT;
+	pck_rng_max_dbl=NC_MAX_INT;
+	break;
+      case NC_SHORT:
+	mss_val_dfl_dbl=NC_FILL_SHORT; 
+	pck_rng_min_dbl=NC_MIN_SHORT;
+	pck_rng_max_dbl=NC_MAX_SHORT;
+	break;
+      case NC_USHORT:
+	mss_val_dfl_dbl=NC_FILL_USHORT;
+	pck_rng_min_dbl=0.0;
+	pck_rng_max_dbl=NC_MAX_USHORT;
+	break;
+      case NC_UINT:
+	mss_val_dfl_dbl=NC_FILL_UINT;
+	pck_rng_min_dbl=0.0;
+	pck_rng_max_dbl=NC_MAX_UINT;
+	break;
+      case NC_INT64:
+	mss_val_dfl_dbl=NC_FILL_INT64; 
+	pck_rng_min_dbl=NC_MIN_INT64;
+	pck_rng_max_dbl=NC_MAX_INT64;
+	break;
+      case NC_UINT64:
+	mss_val_dfl_dbl=NC_FILL_UINT64;
+	pck_rng_min_dbl=0.0;
+	pck_rng_max_dbl=NC_MAX_UINT64;
+	break;
+      case NC_BYTE:
+	mss_val_dfl_dbl=NC_FILL_BYTE; 
+	pck_rng_min_dbl=NC_MIN_BYTE;
+	pck_rng_max_dbl=NC_MAX_BYTE;
+	break;
+      case NC_UBYTE:
+	mss_val_dfl_dbl=NC_FILL_UBYTE;
+	pck_rng_min_dbl=0.0;
+	pck_rng_max_dbl=NC_MAX_UBYTE;
+	break;
+      case NC_CHAR:
+	mss_val_dfl_dbl=NC_FILL_CHAR;
+	pck_rng_min_dbl=0.0;
+	pck_rng_max_dbl=NC_MAX_CHAR;
+	break;
       case NC_STRING: break; /* Do nothing */
       default: nco_dfl_case_nc_type_err(); break;
       } /* end switch */ 
-      if(dbg_lvl_get() >= nco_dbg_io) (void)fprintf(stdout,"%s: %s mss_val_dfl = %g\n",prg_nm_get(),fnc_nm,mss_val_dfl_dbl);
+      if(dbg_lvl_get() >= nco_dbg_io) (void)fprintf(stdout,"%s: %s mss_val_dfl_dbl = %g, pck_rng_min_dbl = %g, pck_rng_max_dbl = %g, \n",prg_nm_get(),fnc_nm,mss_val_dfl_dbl,pck_rng_min_dbl,pck_rng_max_dbl);
+
+      mss_val_dbl=ptr_unn_mss_val_dbl.dp[0];
+      if(nc_typ_pck != NC_STRING && (mss_val_dbl < pck_rng_min_dbl || mss_val_dbl > pck_rng_max_dbl)){ 
+	(void)fprintf(stdout,"%s: WARNING %s reports mss_val_dbl (= %g) is outside range (%g <= x <= %g) represented by packed data type (= %s). Conversion of missing values is unpredictable and could lead to erroneous results. Workaround is to set _FillValue to be within packed range with, e.g.,\nncatted -O -a _FillValue,,o,f,%g inout.nc\nFor more information on this workaround, see\nhttp://nco.sf.net/nco.html#mss_val\n",prg_nm_get(),fnc_nm,mss_val_dbl,pck_rng_min_dbl,pck_rng_max_dbl,nco_typ_sng(nc_typ_pck),mss_val_dfl_dbl);
+      } /* NC_STRING */
     } /* endif */
 
     if(dbg_lvl_get() >= nco_dbg_io) (void)fprintf(stdout,"%s: %s: min_var = %g, max_var = %g\n",prg_nm_get(),var->nm,min_var->val.dp[0],max_var->val.dp[0]);
@@ -837,20 +897,25 @@ nco_var_pck /* [fnc] Pack variable in memory */
 
     /* ndrv is 2^{bits per packed value} where bppv = 8 for NC_CHAR and bppv = 16 for NC_SHORT
        Subtract one to leave slop for rounding errors
-       Subtract two to leave room for missing_value? */
+       20101130 Subtract two to leave room for missing_value */
     if(nc_typ_pck == NC_BYTE || nc_typ_pck == NC_CHAR){
-      ndrv_dbl=256.0-1.0; /* [sct] Double precision value of number of discrete representable values */
+      ndrv_dbl=256.0-2.0; /* [sct] Double precision value of number of discrete representable values */
     }else if(nc_typ_pck == NC_SHORT){
-      ndrv_dbl=65536.0-1.0; /* [sct] Double precision value of number of discrete representable values */
+      /* 20110203 Griffith Young reports: 
+	 "I have noticed some small inconsistencies with the _FillValue values.
+	 short int is [32767, -32768].  The default _FillValue is -32767.  
+	 Therefore a reasonable range would be [32766, -32766] and a reasonable
+	 scale_factor becomes (max - min) -> 32766 - (-32766) -> 65532." */
+      ndrv_dbl=65536.0-4.0; /* [sct] Double precision value of number of discrete representable values */
     }else if(nc_typ_pck == NC_INT){
-      ndrv_dbl=4294967295.0-1.0; /* [sct] Double precision value of number of discrete representable values */
+      ndrv_dbl=4294967295.0-2.0; /* [sct] Double precision value of number of discrete representable values */
     } /* end else */
     ndrv_unn.d=ndrv_dbl; /* Generic container for number of discrete representable values */
     ndrv_var=scl_mk_var(ndrv_unn,NC_DOUBLE); /* [sct] Variable structure for number of discrete representable values */
 
     /* scale_factor is (max-min)/ndrv
-       If max-min = 0 then variable is constant value so scale_factor=0.0 and add_offset=var
-       If max-min > ndrv then precision is worse than 1.0
+       If max-min == 0 then variable is constant value so scale_factor=0.0 and add_offset=var
+       If max-min > ndrv then precision is worse  than 1.0
        If max-min < ndrv then precision is better than 1.0 */
     (void)nco_var_sbt((nc_type)NC_DOUBLE,1L,var->has_mss_val,ptr_unn_mss_val_dbl,min_var->val,max_var_dpl->val);
     /* max-min is currently stored in max_var_dpl */
