@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.29 2010/01/26 13:06:25 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.34 2010/12/21 20:12:07 zender Exp $ */
 
 /* Purpose: String utilities */
 
-/* Copyright (C) 1995--2010 Charlie Zender
+/* Copyright (C) 1995--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -99,13 +99,15 @@ sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII
      The escape sequence for NUL itself, \0, causes a warning and is not translated
      Input string must be NUL-terminated or NULL
      This procedure can only diminish, not lengthen, input string size
-     Therefore it may be performed in place safely, i.e., not string copy is necessary
-     Translation is done in place so copy original prior to calling sng_ascii_trn()!!!
+     Therefore it may safely be performed in-place, i.e., no string copy is necessary
+     Translation is done in-place so copy original prior to calling sng_ascii_trn()!!!
 
      Address pointed to by sng does not change, but memory at that address is altered
      when characters are "moved to the left" if C language escape sequences are embedded.
      Thus string length may shrink */
 
+  const char fnc_nm[]="sng_ascii_trn()"; /* [sng] Function name */
+
   nco_bool trn_flg; /* Translate this escape sequence */
 
   char *backslash_ptr; /* [ptr] Pointer to backslash character */
@@ -135,15 +137,16 @@ sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII
     case 't': *backslash_ptr='\t'; break; /* 011   9     09    HT  '\t' Horizontal tab */
     case 'v': *backslash_ptr='\v'; break; /* 013   11    0B    VT  '\v' Vertical tab */
     case '\\': *backslash_ptr='\\'; break; /* 134   92    5C    \   '\\' */
-    case '\?': *backslash_ptr='\?'; break; /* I'm not sure why or if this one works! */
-    case '\'': *backslash_ptr='\''; break; /* I'm not sure why or if this one works! */
-    case '\"': *backslash_ptr='\"'; break; /* I'm not sure why or if this one works! */
-      /* Do not translate \0 to NUL since this would "erase" the rest of the string */
+    case '\?': *backslash_ptr='\?'; break; /* Unsure why or if this works! */
+    case '\'': *backslash_ptr='\''; break; /* Unsure why or if this works! */
+    case '\"': *backslash_ptr='\"'; break; /* Unsure why or if this works! */
     case '0':	
-      /* Do not translate \0 to NUL since this would make the rest of the string invisible to all string functions */
-      /* *backslash_ptr='\0'; *//* 000   0     00    NUL '\0' */
-      (void)fprintf(stderr,"%s: WARNING C language escape code %.2s found in string, not translating to NUL since this would make the rest of the string invisible to all string functions\n",prg_nm_get(),backslash_ptr);
+      /* Translating \0 to NUL makes subsequent portion of input string invisible to all string functions */
+      (void)fprintf(stderr,"%s: WARNING C language escape code %.2s found in string, not translating to NUL since this would make the subsequent portion of the string invisible to all C Standard Library string functions\n",prg_nm_get(),backslash_ptr); 
       trn_flg=False;
+      /* 20101013: Tried changing above behavior to following, and it opened a Hornet's nest of problems... */
+      /* *backslash_ptr='\0'; *//* 000   0     00    NUL '\0' */
+      /*      (void)fprintf(stderr,"%s: WARNING translating C language escape code \"\\0\" found in user-supplied string to NUL. This will make the subsequent portion of the string, if any, invisible to C Standard Library string functions. And that may cause unintended consequences.\n",prg_nm_get());*/
       break;
     default: 
       (void)fprintf(stderr,"%s: WARNING No ASCII equivalent to possible C language escape code %.2s so no action taken\n",prg_nm_get(),backslash_ptr);
@@ -151,19 +154,19 @@ sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII
       break;
     } /* end switch */
     if(trn_flg){
-      /* Get rid of character after backslash character */
+      /* Remove character after backslash character */
       (void)memmove(backslash_ptr+1,backslash_ptr+2,(strlen(backslash_ptr+2)+1)*sizeof(char));
       /* Count translations performed */
       trn_nbr++;
     } /* end if */
     /* Look for next backslash starting at character following current escape sequence (but remember that not all escape sequences are translated) */
-    if (trn_flg) backslash_ptr=strchr(backslash_ptr+1,backslash_chr); else backslash_ptr=strchr(backslash_ptr+2,backslash_chr);
+    if(trn_flg) backslash_ptr=strchr(backslash_ptr+1,backslash_chr); else backslash_ptr=strchr(backslash_ptr+2,backslash_chr);
     /* Count escape sequences */
     esc_sqn_nbr++;
   } /* end if */
 
   /* Usually there are no escape codes and sng still equals input value */
-  if(dbg_lvl_get() > 3) (void)fprintf(stderr,"%s: DEBUG sng_ascii_trn() Found %d C-language escape sequences, translated %d of them\n",prg_nm_get(),esc_sqn_nbr,trn_nbr);
+  if(dbg_lvl_get() > 3) (void)fprintf(stderr,"%s: DEBUG %s Found %d C-language escape sequences, translated %d of them\n",prg_nm_get(),fnc_nm,esc_sqn_nbr,trn_nbr);
 
   return trn_nbr;
 } /* end sng_ascii_trn() */
