@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.167 2011/02/19 02:28:37 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_utl.c,v 1.168 2011/03/04 23:35:29 zender Exp $ */
 
 /* Purpose: Variable utilities */
 
@@ -1255,7 +1255,7 @@ nco_var_fll /* [fnc] Allocate variable structure and fill with metadata */
 
     if(dmn_idx == nbr_dim){
       (void)fprintf(stdout,"%s: ERROR dimension %s is not in list of dimensions available to nco_var_fll()\n",prg_nm_get(),dmn_nm);
-      (void)fprintf(stdout,"%s: HINT This could be the problem identified in TODO #111. Workaround is to make sure each dimension in the weighting and masking variable(s) appears in a variable to be processed.\n",prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT This could be a symptom of TODO nco111. Workaround is to make sure each dimension in the weighting and masking variable(s) appears in a variable to be processed.\n",prg_nm_get());
       nco_exit(EXIT_FAILURE);
     } /* end if */
 
