@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.289 2011/01/01 02:28:48 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncwa.c,v 1.290 2011/04/26 22:56:28 zender Exp $ */
 
 /* ncwa -- netCDF weighted averager */
 
@@ -122,8 +122,8 @@ main(int argc,char **argv)
   char *sng_cnv_rcd=char_CEWI; /* [sng] strtol()/strtoul() return code */
   char *wgt_nm=NULL;
 
-  const char * const CVS_Id="$Id: ncwa.c,v 1.289 2011/01/01 02:28:48 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.289 $";
+  const char * const CVS_Id="$Id: ncwa.c,v 1.290 2011/04/26 22:56:28 zender Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.290 $";
   const char * const opt_sht_lst="346Aa:B:bCcD:d:FhIL:l:M:m:nNOo:p:rRT:t:v:Ww:xy:-:";
   
   cnk_sct **cnk=NULL_CEWI;
@@ -728,7 +728,7 @@ main(int argc,char **argv)
   if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) (void)nco_cnk_sz_set(out_id,lmt_all_lst,nbr_dmn_fl,&cnk_map,&cnk_plc,cnk_sz_scl,cnk,cnk_nbr);
 
   /* Turn off default filling behavior to enhance efficiency */
-  rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+  /*rcd=nco_set_fill(out_id,NC_NOFILL,&fll_md_old);*/
   
   /* Take output file out of define mode */
   (void)nco_enddef(out_id);
