@@ -1,8 +1,8 @@
-// $Header: /cvsroot/nco/nco/src/nco_c++/nco_utl.cc,v 1.23 2010/01/05 20:02:18 zender Exp $ 
+// $Header: /cvsroot/nco/nco/src/nco_c++/nco_utl.cc,v 1.25 2010/12/21 20:12:07 zender Exp $ 
 
 // Implementation (declaration) of C++ interface utilities for netCDF routines
 
-/* Copyright (C) 2001--2010 Charlie Zender
+/* Copyright (C) 2001--2011 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -194,7 +194,7 @@ nco_typ_lng // [fnc] Internal (native) size (Bytes) of netCDF external type
   case NC_INT: 
     return sizeof(long); 
   case NC_SHORT: 
-    return sizeof(short); 
+    return sizeof(short int); 
   case NC_CHAR: 
     return sizeof(unsigned char); 
   case NC_BYTE: 
